@@ -1,4 +1,4 @@
-/* $Id: blast_seqalign.c,v 1.60 2006/06/13 14:42:44 papadopo Exp $
+/* $Id: blast_seqalign.c,v 1.64 2010/02/12 20:54:54 maning Exp $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -29,7 +29,7 @@
  */
 
 #ifndef SKIP_DOXYGEN_PROCESSING
-static char const rcsid[] = "$Id: blast_seqalign.c,v 1.60 2006/06/13 14:42:44 papadopo Exp $";
+static char const rcsid[] = "$Id: blast_seqalign.c,v 1.64 2010/02/12 20:54:54 maning Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 
 #include <algo/blast/api/blast_seqalign.h>
@@ -82,10 +82,6 @@ SBlastSeqalignArrayFree(SBlastSeqalignArray* seqalign_vec)
    return NULL;
 }
 
-/** Creates a score set corresponding to one HSP.
- * @param hsp HSP structure [in]
- * @return Score set for this HSP.
- */
 ScorePtr 
 GetScoreSetFromBlastHsp(BlastHSP* hsp)
 {
@@ -716,7 +712,7 @@ s_GapMakeSeqAlign(SeqIdPtr query_id, SeqIdPtr subject_id,
 
 SeqAlignPtr
 BlastHSPToSeqAlign(EBlastProgramType program, BlastHSP* hsp, 
-                   SeqIdPtr subject_id, SeqIdPtr query_id,
+                   SeqIdPtr query_id, SeqIdPtr subject_id,
                    Int4 query_length, Int4 subject_length)
 
 {
@@ -743,10 +739,8 @@ BlastHSPToSeqAlign(EBlastProgramType program, BlastHSP* hsp,
     
     start1 = hsp->query.offset;
     start2 = hsp->subject.offset;
-    translate1 = (program == eBlastTypeBlastx || program == eBlastTypeTblastx ||
-                  program == eBlastTypeRpsTblastn);
-    translate2 = (program == eBlastTypeTblastn || program == eBlastTypeTblastx);
-
+    translate1 = Blast_QueryIsTranslated(program);
+    translate2 = Blast_SubjectIsTranslated(program);
     
     /* If no eGapAlignDecline regions exists output seqalign will be
        regular Den-Seg or Std-seg */
@@ -1277,8 +1271,8 @@ s_HSPListToSeqAlignGapped(EBlastProgramType program_number,
          /* The following line is needed for negative frames of translated 
             query */
          seqalign = 
-             BlastHSPToSeqAlign(program_number, hsp_array[index], subject_id, 
-                                query_id, query_length, subject_length);
+             BlastHSPToSeqAlign(program_number, hsp_array[index], query_id, 
+                                subject_id, query_length, subject_length);
       }
       if (index==0) {
          *head_seqalign = last_seqalign = seqalign;
