@@ -1,4 +1,4 @@
-/* $Id: blast_nalookup.c,v 1.21 2016/07/06 14:44:15 fukanchi Exp $
+/* $Id: blast_nalookup.c,v 1.28 2017/01/05 16:34:16 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -1451,6 +1451,139 @@ s_NaHashLookupFillPV(BLAST_SequenceBlk* query,
     return 0;
 }
 
+/* Get number of set bits (adapted 	 
+   from http://graphics.stanford.edu/~seander/bithacks.html) 	 
+   @param v Bit vector [in] 	 
+   @return Number of set bits 	 
+*/ 	 
+static Uint4 s_Popcount(Uint4 v) 	 
+{ 	 
+    if (v==0) return 0; // early bailout for sparse vectors 	 
+    v = v - ((v >> 1) & 0x55555555); 	 
+    v = (v & 0x33333333) + ((v >> 2) & 0x33333333); 	 
+    v = ((v + (v >> 4)) & 0xF0F0F0F); 	 
+    v = v * 0x1010101; 	 
+	  	 
+    return v >> 24; // count 	 
+} 	 
+
+/** Sparse array of Uint1 implemented with a bitfield. The implementation
+    assumes that indices present are known beforehand and the array is used
+    only to access values with certain indices */
+typedef struct BlastSparseUint1Array
+{
+    Uint4* bitfield;       /**< bitfield with bits set for present indices */
+    Uint1* values;         /**< array of values for present indices */
+    Int4* counts;          /**< cumulative number of bits set */
+    Uint4 num_elements;    /**< number of values present in the array */
+    Uint4 length;          /**< length of the bitfield */
+} BlastSparseUint1Array;
+
+
+static BlastSparseUint1Array*
+BlastSparseUint1ArrayFree(BlastSparseUint1Array* array)
+{
+    if (!array) {
+        return NULL;
+    }
+
+    if (array->values) {
+        free(array->values);
+    }
+
+    if (array->counts) {
+        free(array->counts);
+    }
+
+    free(array);
+
+    return NULL;
+}
+
+static BlastSparseUint1Array*
+BlastSparseUint1ArrayNew(Uint4* bitfield, Int8 len)
+{
+    Int4 i;
+    BlastSparseUint1Array* retval = calloc(1, sizeof(BlastSparseUint1Array));
+    
+    if (!retval || !bitfield) {
+        return NULL;
+    }
+
+    retval->bitfield = bitfield;
+    retval->length = len >> PV_ARRAY_BTS;
+    retval->counts = calloc(retval->length, sizeof(Int4));
+    if (!retval->counts) {
+        BlastSparseUint1ArrayFree(retval);
+        return NULL;
+    }
+
+    retval->counts[0] = s_Popcount(retval->bitfield[0]);
+    for (i = 1;i < retval->length;i++) {
+        retval->counts[i] = retval->counts[i - 1] +
+            s_Popcount(retval->bitfield[i]);
+    }
+
+    Int4 num_elements = retval->counts[retval->length - 1];
+    retval->num_elements = num_elements;
+    retval->values = calloc(num_elements, sizeof(Uint1));
+    if (!retval->values) {
+        BlastSparseUint1ArrayFree(retval);
+        return NULL;
+    }
+
+    return retval;
+}
+
+/* Get index into array->values for a given vector index */
+static Int4
+BlastSparseUint1ArrayGetIndex(BlastSparseUint1Array* array, Int8 index)
+{
+    /* index into bitfield */
+    Int4 idx = index >> PV_ARRAY_BTS;
+
+    /* bit number within a bitfield cell (mod 32) */
+    Int4 bit_number = index & PV_ARRAY_MASK;
+
+    /* number of bits set before a specified bit */
+    Int4 bit_count = 0;
+
+    if (!array || idx >= array->length) {
+        return -1;
+    }
+
+    /* get number of bits set up to idx */
+    bit_count = (idx > 0) ? array->counts[idx - 1] : 0;
+    ASSERT(array->bitfield[idx] & (1 << bit_number));
+
+    /* add number of bits set up to bit number in the cell */
+    bit_count += s_Popcount(array->bitfield[idx] & ((1 << bit_number) - 1));
+    bit_count++;
+
+
+    ASSERT(bit_count > 0);
+    return bit_count - 1;
+}
+
+/* Get a pointer to a non zero element in the  sparse vector */
+static Uint1*
+BlastSparseUint1ArrayGetElement(BlastSparseUint1Array* array, Int8 index)
+{
+    Int4 sparse_index;
+
+    if (!array) {
+        return NULL;
+    }
+
+    sparse_index = BlastSparseUint1ArrayGetIndex(array, index);
+    ASSERT(sparse_index < array->num_elements);
+    if (sparse_index < 0 || sparse_index > array->num_elements) {
+        return NULL;
+    }
+
+    return array->values + sparse_index;
+}
+
 
 /** Scan a subject sequecne and update words counters, for 16-base words with
  *  scan step of 1. The counters are 4-bit and counting is done up to 10.
@@ -1462,18 +1595,19 @@ s_NaHashLookupFillPV(BLAST_SequenceBlk* query,
 static Int2
 s_NaHashLookupCountWordsInSubject_16_1(const BLAST_SequenceBlk* sequence,
                                        BlastNaHashLookupTable* lookup,
-                                       Uint1* counts)
+                                       BlastSparseUint1Array* counts)
 {
     Uint1 *s;
     Int4 i;
     Int8 mask = (1ULL << (16 * BITS_PER_NUC)) - 1;
-    Int8 word, index, w;
+    Int8 word, w;
     const Int4 kNumWords
         = sequence->length - lookup->lut_word_length;
 
     PV_ARRAY_TYPE* pv = lookup->pv;
     Int4 pv_array_bts = lookup->pv_array_bts;
     Int4 shift;
+    Uint1* pelem;
 
     if (!sequence || !counts || !lookup || !pv) {
         return -1;
@@ -1504,128 +1638,337 @@ s_NaHashLookupCountWordsInSubject_16_1(const BLAST_SequenceBlk* sequence,
         }
 
         /* update the counter */
-        index = word / 2;
-        if (word & 1) {
-            if ((counts[index] & 0xf) < MAX_WORD_COUNT) {
-                counts[index]++;
-            }
-        }
-        else {
-            if ((counts[index] >> 4) < MAX_WORD_COUNT) {
-                counts[index] += 1 << 4;
-            }
+        pelem = BlastSparseUint1ArrayGetElement(counts, word);
+        if (*pelem < MAX_WORD_COUNT) {
+            (*pelem)++;
         }
     }
 
     return 0;
 }
 
+
+/* Thread local data for database word counting phase of lookup table
+   generation (for Magic-BLAST) */
+typedef struct NaHashLookupThreadData
+{
+    BlastSeqSrcGetSeqArg* seq_arg;
+    BlastSeqSrcIterator** itr;
+    BlastSeqSrc** seq_src;
+    BlastSparseUint1Array** word_counts;
+    Int4 num_threads;
+} NaHashLookupThreadData;
+
+
+static NaHashLookupThreadData* NaHashLookupThreadDataFree(
+                                                  NaHashLookupThreadData* th)
+{
+    if (!th) {
+        return NULL;
+    }
+
+    if (th->seq_arg) {
+        Int4 i;
+        for (i = 0;i < th->num_threads;i++) {
+            BlastSequenceBlkFree(th->seq_arg[i].seq);
+        }
+        free(th->seq_arg);
+    }
+
+    if (th->itr) {
+        Int4 i;
+        for (i = 0;i < th->num_threads;i++) {
+            BlastSeqSrcIteratorFree(th->itr[i]);
+        }
+        free(th->itr);
+    }
+
+    if (th->seq_src) {
+        Int4 i;
+        for (i = 0;i < th->num_threads;i++) {
+            BlastSeqSrcFree(th->seq_src[i]);
+        }
+        free(th->seq_src);
+    }
+
+    if (th->word_counts) {
+        Int4 i;
+        for (i = 1;i < th->num_threads;i++) {
+            if (th->word_counts[i]) {
+                if (th->word_counts[i]->values) {
+                    free(th->word_counts[i]->values);
+                }
+                free(th->word_counts[i]);
+            }
+
+
+        }
+        BlastSparseUint1ArrayFree(th->word_counts[0]);
+        free(th->word_counts);
+    }
+
+    free(th);
+
+    return NULL;
+}
+
+
+static NaHashLookupThreadData* NaHashLookupThreadDataNew(Int4 num_threads,
+                                               BlastNaHashLookupTable* lookup,
+                                               BlastSeqSrc* seq_src)
+{
+    Int4 i;
+
+    if (num_threads < 1 || !lookup || !seq_src) {
+        return NULL;
+    }
+
+    NaHashLookupThreadData* retval = calloc(1, sizeof(NaHashLookupThreadData));
+    if (!retval) {
+        return NULL;
+    }
+
+    retval->seq_arg = calloc(num_threads, sizeof(BlastSeqSrcGetSeqArg));
+    if (!retval->seq_arg) {
+        NaHashLookupThreadDataFree(retval);
+        return NULL;
+    }
+
+    retval->itr = calloc(num_threads, sizeof(BlastSeqSrcIterator*));
+    if (!retval->itr) {
+        NaHashLookupThreadDataFree(retval);
+        return NULL;
+    }
+
+    retval->seq_src = calloc(num_threads, sizeof(BlastSeqSrc*));
+    if (!retval->seq_src) {
+        NaHashLookupThreadDataFree(retval);
+        return NULL;
+    }
+
+    retval->word_counts = calloc(num_threads, sizeof(BlastSparseUint1Array*));
+    if (!retval->word_counts) {
+        NaHashLookupThreadDataFree(retval);
+        return NULL;
+    }
+
+    for (i = 0;i < num_threads;i++) {
+            
+        retval->seq_arg[i].encoding = eBlastEncodingProtein;
+
+        retval->seq_src[i] = BlastSeqSrcCopy(seq_src);
+        if (!retval->seq_src[i]) {
+            NaHashLookupThreadDataFree(retval);
+            return NULL;
+        }
+
+        /* each thread must have its own iterator, the small batch seems to
+           work better for work balansing between threads */
+        retval->itr[i] = BlastSeqSrcIteratorNewEx(1);
+        if (!retval->itr[i]) {
+            NaHashLookupThreadDataFree(retval);
+            return NULL;
+        }
+
+        if (i == 0) {
+            retval->word_counts[i] = BlastSparseUint1ArrayNew(lookup->pv,
+                                        1LL << (2 * lookup->lut_word_length));
+
+            if (!retval->word_counts[i]) {
+                NaHashLookupThreadDataFree(retval);
+                return NULL;
+            }
+        }
+        else {
+            /* Make shallow copies of the counts array. We do not copy data
+               that are read only to save memory. */
+            retval->word_counts[i] = malloc(sizeof(BlastSparseUint1Array));
+            if (!retval->word_counts[i]) {
+                NaHashLookupThreadDataFree(retval);
+                return NULL;
+            }
+            memcpy(retval->word_counts[i], retval->word_counts[0],
+                   sizeof(BlastSparseUint1Array));
+
+            retval->word_counts[i]->values = calloc(
+                                        retval->word_counts[i]->num_elements,
+                                        sizeof(Uint1));
+
+            if (!retval->word_counts[i]->values) {
+                NaHashLookupThreadDataFree(retval);
+                return NULL;
+            }
+        }
+    }
+
+    retval->num_threads = num_threads;
+
+    return retval;
+}
+
 /** Scan database sequences and count query words that appear in the database.
  *  Then reset pv_array bits that correspond to words that do not appear in
  *  in the database, or appear 10 or more times
  *
  * @param seq_src Source for subject sequences [in]
  * @param lookup Hashed lookuptable [in|out]
+ * @param num_threads Number of threads to use [in]
  */
 static Int2
 s_NaHashLookupScanSubjectForWordCounts(BlastSeqSrc* seq_src,
                                        BlastNaHashLookupTable* lookup,
-                                       Uint1* counts)
+                                       Uint4 in_num_threads)
 {
-    BlastSeqSrcIterator* itr;
-    BlastSeqSrcGetSeqArg seq_arg;
+    Uint4 i;
+    Int4 k, b;
+    Int4 num_db_seqs, th_batch;
+    NaHashLookupThreadData* th_data = NULL;
+    Uint4 num_threads;
 
-    if (!seq_src || !lookup || !lookup->pv || !counts) {
+    if (!seq_src || !lookup || !lookup->pv) {
         return -1;
     }
 
-    memset(&seq_arg, 0, sizeof(seq_arg));
-    seq_arg.encoding = eBlastEncodingProtein;
+    ASSERT(lookup->lut_word_length == 16);
 
-    /* scan subject sequences and update the counters for each */
-    BlastSeqSrcResetChunkIterator(seq_src);
-    itr = BlastSeqSrcIteratorNewEx(MAX(BlastSeqSrcGetNumSeqs(seq_src)/100,1));
-    while ((seq_arg.oid = BlastSeqSrcIteratorNext(seq_src, itr))
-           != BLAST_SEQSRC_EOF) {
+    /* pv array must be one bit per word */
+    ASSERT(lookup->pv_array_bts == 5);
 
-        BlastSeqSrcGetSequence(seq_src, &seq_arg);
-        s_NaHashLookupCountWordsInSubject_16_1(seq_arg.seq, lookup, counts);
-        BlastSeqSrcReleaseSequence(seq_src, &seq_arg);
+    num_db_seqs = BlastSeqSrcGetNumSeqs(seq_src);
+    num_threads = MIN(in_num_threads, num_db_seqs);
+    th_batch = BlastSeqSrcGetNumSeqs(seq_src) / num_threads;
+
+    th_data = NaHashLookupThreadDataNew(num_threads, lookup, seq_src);
+    if (!th_data) {
+        return -1;
     }
 
-    BlastSequenceBlkFree(seq_arg.seq);
-    BlastSeqSrcIteratorFree(itr);
+    /* reset database iterator */
+    BlastSeqSrcResetChunkIterator(seq_src);
+
+    /* scan subject sequences and update the counters for each */
+#pragma omp parallel for if (num_threads > 1) num_threads(num_threads) \
+   default(none) shared(num_threads, th_data, lookup, \
+                        th_batch) private(i) schedule(dynamic, 1)
+
+    for (i = 0;i < num_threads;i++) {
+        Int4 j;
+        for (j = 0;j < th_batch;j++) {
+
+#pragma omp critical (get_sequence_for_word_counts)
+            {
+                th_data->seq_arg[i].oid = BlastSeqSrcIteratorNext(
+                                                         th_data->seq_src[i],
+                                                         th_data->itr[i]);
+
+                if (th_data->seq_arg[i].oid != BLAST_SEQSRC_EOF) {
+                    BlastSeqSrcGetSequence(th_data->seq_src[i],
+                                           &th_data->seq_arg[i]);
+                }
+            }
+
+            if (th_data->seq_arg[i].oid != BLAST_SEQSRC_EOF) {
+
+                s_NaHashLookupCountWordsInSubject_16_1(th_data->seq_arg[i].seq,
+                                                       lookup,
+                                                       th_data->word_counts[i]);
+                BlastSeqSrcReleaseSequence(th_data->seq_src[i],
+                                           &th_data->seq_arg[i]);
+            }
+        }
+    }
+
+    /* scan the last sequences */
+    while ((th_data->seq_arg[0].oid = BlastSeqSrcIteratorNext(seq_src,
+                                                              th_data->itr[0]))
+           != BLAST_SEQSRC_EOF) {
+
+        BlastSeqSrcGetSequence(seq_src, &th_data->seq_arg[0]);
+        s_NaHashLookupCountWordsInSubject_16_1(th_data->seq_arg[0].seq, lookup,
+                                               th_data->word_counts[0]);
+        BlastSeqSrcReleaseSequence(seq_src, &th_data->seq_arg[0]);
+    }
+
+    /* aggregate counts */
+    for (i = 0;i < th_data->word_counts[0]->num_elements;i++) {
+        for (k = 1;k < num_threads;k++) {
+            th_data->word_counts[0]->values[i] =
+                MIN(th_data->word_counts[0]->values[i] +
+                    th_data->word_counts[k]->values[i],
+                    MAX_WORD_COUNT);
+        }
+    }
+    
+    /* iterate over word counts and clear bits for words that appear too
+       often or not at all */
+    i = 0;
+    b = 1;
+    k = 0;
+    while (i < th_data->word_counts[0]->length) {
+
+        /* skip bit field array elements with all bits cleared */
+        if (th_data->word_counts[0]->bitfield[i] == 0) {
+            i++;
+            b = 1;
+            continue;
+        }
+
+        if (th_data->word_counts[0]->bitfield[i] & b) {
+            ASSERT(k < th_data->word_counts[0]->num_elements);
+
+            /* clear bit if word count is too low or too large */
+            if (th_data->word_counts[0]->values[k] == 0 ||
+                th_data->word_counts[0]->values[k] >= MAX_WORD_COUNT) {
+
+                th_data->word_counts[0]->bitfield[i] &= ~b;
+            }
+            k++;
+        }
+        b <<= 1;
+        if (b == 0) {
+            i++;
+            b = 1;
+        }
+    }
+
+    NaHashLookupThreadDataFree(th_data);
 
     return 0;
 }
 
 
-static void s_NaHashLookupRemoveWordFromThinBackbone(
-                                         BackboneCell** thin_backbone,
-                                         Uint4 word,
-                                         TNaLookupHashFunction hash_func,
-                                         Uint4 mask)
+static Int2 s_NaHashLookupRemovePolyAWords(BlastNaHashLookupTable* lookup)
 {
-    BackboneCell* prev = NULL;
-    BackboneCell* next = NULL;
-    BackboneCell* b = NULL;
-    Int8 index = hash_func((Uint1*)&word, mask);
-
-    if (!thin_backbone[index]) {
-        return;
-    }
-
-    /* if word present in the first enrty for the hashed value */
-    if (thin_backbone[index]->word == word) {
-        next = thin_backbone[index]->next;
-        thin_backbone[index]->next = NULL;
-        BackboneCellFree(thin_backbone[index]);
-        thin_backbone[index] = next;
-
-        return;
-    }
-
-    /* in case of a collision check the remaining words with the same hash
-       value */
-    prev = thin_backbone[index];
-    b = thin_backbone[index]->next;
-    for (; b; prev = prev->next, b = b->next) {
-        if (b->word == word) {
-            next = b->next;
-            b->next = NULL;
-            BackboneCellFree(b);
-            prev->next = next;
-
-            break;
-        }
-    }
-}
-
-
-static Int2 s_NaHashLookupRemovePolyAWords(BackboneCell** thin_backbone,
-                                           Int4 size,
-                                           TNaLookupHashFunction hash_func,
-                                           Uint4 mask)
-{
-    Int4 word_size = 16;
     Int8 word;
+    Int4 word_size;
     Int4 i, k;
+    PV_ARRAY_TYPE* pv = NULL;
+    Int4 pv_array_bts;
 
-    ASSERT(word_size == 16);
+    if (!lookup) {
+        return -1;
+    }
+
+    ASSERT(lookup->lut_word_length == 16);
+
+    /* a bit must represent a single word */
+    ASSERT(lookup->pv_array_bts == 5);
+
+    pv = lookup->pv;
+    pv_array_bts = lookup->pv_array_bts;
+    word_size = lookup->lut_word_length;
 
     /* remove As and Ts */
-    s_NaHashLookupRemoveWordFromThinBackbone(thin_backbone, 0, hash_func, mask);
-    s_NaHashLookupRemoveWordFromThinBackbone(thin_backbone, 0xffffffff,
-                                             hash_func, mask);
+    pv[0] &= ~(PV_ARRAY_TYPE)1;
+    pv[0xffffffff >> pv_array_bts] &=
+        ~((PV_ARRAY_TYPE)1 << (0xffffffff & PV_ARRAY_MASK));
 
     /* remove As with a single error */
     for (i = 1;i < 4;i++) {
         word = i;
         for (k = 0;k < word_size;k++) {
-            s_NaHashLookupRemoveWordFromThinBackbone(thin_backbone,
-                                                     word << (k * 2),
-                                                     hash_func,
-                                                     mask);
+            pv[word >> pv_array_bts] &=
+                ~((PV_ARRAY_TYPE)1 << (word & PV_ARRAY_MASK));
         }
     }
 
@@ -1633,8 +1976,9 @@ static Int2 s_NaHashLookupRemovePolyAWords(BackboneCell** thin_backbone,
     for (i = 0;i < 3;i++) {
         for (k = 0;k < word_size;k++) {
             word = ((0xffffffff ^ (3 << k*2)) | (i << k*2)) & 0xffffffff;
-            s_NaHashLookupRemoveWordFromThinBackbone(thin_backbone, word,
-                                                     hash_func, mask);
+
+            pv[word >> pv_array_bts] &=
+                ~((PV_ARRAY_TYPE)1 << (word & PV_ARRAY_MASK));
         }
     }
 
@@ -1647,7 +1991,8 @@ static Int2 s_NaHashLookupRemovePolyAWords(BackboneCell** thin_backbone,
  * @param thin_backbone structure containing indexed query offsets [in][out]
  * @param lookup the lookup table [in]
  */
-static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
+static void s_BlastNaHashLookupFinalize(BackboneCell* thin_backbone,
+                                        Int4* offsets,
                                         BlastNaHashLookupTable* lookup)
 {
     Int4 i;
@@ -1656,6 +2001,7 @@ static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
     Int4 longest_chain = 0;
     PV_ARRAY_TYPE *pv;
     const Int4 pv_array_bts = lookup->pv_array_bts;
+    const Int8 kNumWords = 1LL << (2 * lookup->lut_word_length);
 #ifdef LOOKUP_VERBOSE
     Int4 backbone_occupancy = 0;
     Int4 thick_backbone_occupancy = 0;
@@ -1665,30 +2011,37 @@ static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
 
     ASSERT(lookup->lut_word_length == 16);
 
+    if (!lookup->pv) {
+
+        lookup->pv = (PV_ARRAY_TYPE*)calloc(kNumWords >> lookup->pv_array_bts,
+                        sizeof(PV_ARRAY_TYPE));
+        ASSERT(lookup->pv);
+    }
+    else {
+        /* reset PV array, it might have been set earlier to count database
+           words, and a few bits may need to be reset */
+        memset(lookup->pv, 0, (kNumWords >> lookup->pv_array_bts) *
+               sizeof(PV_ARRAY_TYPE));
+    }
+    pv = lookup->pv;
+    ASSERT(pv != NULL);
+
     /* allocate the new lookup table */
     lookup->thick_backbone = (NaHashLookupBackboneCell *)calloc(
                                            lookup->backbone_size, 
                                            sizeof(NaHashLookupBackboneCell));
     ASSERT(lookup->thick_backbone != NULL);
 
-    pv = lookup->pv;
-    ASSERT(pv != NULL);
-    /* reset PV array, it might have been set earlier to count database words,
-       and a few bits may need to be reset */
-    memset(pv, 0, (lookup->backbone_size >> pv_array_bts) * PV_ARRAY_BYTES);
-
-    /* remove polyA words from the lookup table */
-    s_NaHashLookupRemovePolyAWords(thin_backbone, lookup->backbone_size,
-                                   lookup->hash_callback, lookup->mask);
-
     /* find out how many cells are needed for the overflow array */
     for (i = 0; i < lookup->backbone_size; i++) {
-        BackboneCell* b = thin_backbone[i];
+        BackboneCell* b = &thin_backbone[i];
         Int4 num_hits = 0;
         Int4 num_words = 0;
-        for (; b; b = b->next) {
-            num_hits += b->num_offsets;
-            num_words++;
+        if (b->num_offsets > 0) {
+            for (; b; b = b->next) {
+                num_hits += b->num_offsets;
+                num_words++;
+            }
         }
 
         if (num_words > NA_WORDS_PER_HASH || num_hits > NA_OFFSETS_PER_HASH) {
@@ -1713,11 +2066,11 @@ static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
         Int4 num_words = 0;
         Int4 num_offsets = 0;
         NaHashLookupBackboneCell* cell = lookup->thick_backbone + i;
-        BackboneCell* head = thin_backbone[i];
+        BackboneCell* head = &thin_backbone[i];
         BackboneCell* b = NULL;
         Boolean is_overflow = FALSE;
         
-        if (!head) {
+        if (head->num_offsets == 0) {
             continue;
         }
 
@@ -1755,9 +2108,12 @@ static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
 
                 PV_SET(pv, (Int8)b->word, pv_array_bts);
 
-                for (j = 0;j < b->num_offsets;j++) {
+                j = b->offset;
+                while (j != 0) {
                     ASSERT(n <= NA_OFFSETS_PER_HASH);
-                    cell->offsets[n++] = b->offsets[j];
+                    /* offsets array stores 1-based offsets */
+                    cell->offsets[n++] = j - 1;
+                    j = offsets[j];
                 }
             }
         }
@@ -1784,18 +2140,22 @@ static void s_BlastNaHashLookupFinalize(BackboneCell** thin_backbone,
                 Int4 j;
                 lookup->overflow[overflow_cursor++] = *(Int4*)(&b->word);
                 lookup->overflow[overflow_cursor++] = b->num_offsets;
-                for (j = 0;j < b->num_offsets;j++) {
-                    lookup->overflow[overflow_cursor++] = b->offsets[j];
+
+                j = b->offset;
+                while (j != 0) {
+                    /* offsets array stores 1-based offsets */
+                    lookup->overflow[overflow_cursor++] = j - 1;
+                    j = offsets[j];
                 }
+
                 ASSERT(overflow_cursor <= overflow_cells_needed);
                 PV_SET(pv, (Int8)b->word, pv_array_bts);
             }
         }
 
         /* done with this chain */
-        thin_backbone[i] = BackboneCellFree(thin_backbone[i]);
+        BackboneCellFree(thin_backbone[i].next);
     }
-
     lookup->offsets_size = overflow_cursor;
 
 #ifdef LOOKUP_VERBOSE
@@ -1826,7 +2186,8 @@ BlastNaHashLookupTableDestruct(BlastNaHashLookupTable* lookup)
     sfree(lookup->overflow);
     if (lookup->masked_locations)
        lookup->masked_locations = BlastSeqLocFree(lookup->masked_locations);
-    sfree(lookup->pv);
+    if (lookup->pv)
+        sfree(lookup->pv);
     sfree(lookup);
 
     return NULL;
@@ -1838,89 +2199,89 @@ Int4 BlastNaHashLookupTableNew(BLAST_SequenceBlk* query,
                                BlastNaHashLookupTable** lut,
                                const LookupTableOptions* opt, 
                                const QuerySetUpOptions* query_options,
-                               BlastSeqSrc* seqsrc)
+                               BlastSeqSrc* seqsrc,
+                               Uint4 num_threads)
 {
-    BackboneCell **thin_backbone = NULL;
+    BackboneCell *thin_backbone = NULL;
+    Int4* offsets = NULL;
     BlastNaHashLookupTable *lookup = *lut =
         (BlastNaHashLookupTable*) calloc(1, sizeof(BlastNaHashLookupTable));
     /* Number of possible 16-base words */
     const Int8 kNumWords = (1ULL << 32);
-    Uint1* counts = NULL;
-    Int4 num_hash_bits = 24;
-    Int8 database_length = 0LL;
-
+    Int4 num_hash_bits = 8;
+    Int4 i, num_unique_words = 0;
+    
     ASSERT(lookup != NULL);
 
     if (opt->db_filter && !seqsrc) {
         return -1;
     }
 
-    /* use more bits for hash function for larger databases to decrease number
-       of collisions */
-    /* FIXME: number of bits may also depend on concatenated query length */
-    if (seqsrc) {
-        database_length = BlastSeqSrcGetTotLen(seqsrc);
-    }
-    if (database_length > 500000000L) {
-        num_hash_bits = 25;
-    }
-
     lookup->word_length = opt->word_size;
     lookup->lut_word_length = 16;
-    /* 16-base words are hashed to 24-bit or 25-bit values */
-    lookup->backbone_size = 1 << num_hash_bits;
-    lookup->mask = lookup->backbone_size - 1;
     lookup->overflow = NULL;
     lookup->scan_step = lookup->word_length - lookup->lut_word_length + 1;
     lookup->hash_callback = FNV_hash;
 
-    thin_backbone = (BackboneCell**)calloc(lookup->backbone_size,
-                                          sizeof(BackboneCell*));
-    ASSERT(thin_backbone != NULL);
-
-    /* PV array does not use hashing, and uses 64 words per bit */
-    lookup->pv_array_bts = 11;
-    lookup->pv = (PV_ARRAY_TYPE*)calloc(kNumWords / 64 / PV_ARRAY_BYTES,
+    /* PV array does not use hashing */
+    lookup->pv_array_bts = PV_ARRAY_BTS;
+    lookup->pv = (PV_ARRAY_TYPE*)calloc(kNumWords >> lookup->pv_array_bts,
                                         sizeof(PV_ARRAY_TYPE));
-    ASSERT(lookup->pv);
+    if (!lookup->pv) {
+        return BLASTERR_MEMORY;
+    }
 
-    
-    /* allocate word counters, to save memory we are using 4 bits per word */
-    if (opt->db_filter) {
-        ASSERT(lookup->word_length == 16);
-        counts = (Uint1*)calloc(kNumWords / 2, sizeof(Uint1));
-        if (counts == NULL) {
-    	    sfree(thin_backbone);
-            BlastNaHashLookupTableDestruct(lookup);
-            return -1;
-        }
-    }  
+    s_NaHashLookupFillPV(query, locations, lookup);
+    s_NaHashLookupRemovePolyAWords(lookup);
 
     /* count words in the database */
     if (opt->db_filter) {
-        s_NaHashLookupFillPV(query, locations, lookup);
-        s_NaHashLookupScanSubjectForWordCounts(seqsrc, lookup, counts);
+        s_NaHashLookupScanSubjectForWordCounts(seqsrc, lookup, num_threads);
+    }
+
+    /* find number of unique query words */
+    for (i = 0;i < kNumWords >> lookup->pv_array_bts; i++) {
+        num_unique_words += s_Popcount(lookup->pv[i]);
+    }
+
+    /* find number of bits to use for hash function */
+    while (num_hash_bits < 32 &&
+           (1LL << num_hash_bits) < num_unique_words) {
+        num_hash_bits++;
+    }
+
+    lookup->backbone_size = 1 << num_hash_bits;
+    lookup->mask = lookup->backbone_size - 1;
+
+    thin_backbone = calloc(lookup->backbone_size, sizeof(BackboneCell));
+    if (!thin_backbone) {
+        return BLASTERR_MEMORY;
+    }
+
+    /* it will store 1-based offsets, hence length + 1 */
+    offsets = calloc(query->length + 1, sizeof(Int4));
+    if (!offsets) {
+        return BLASTERR_MEMORY;
     }
 
-    
     BlastHashLookupIndexQueryExactMatches(thin_backbone,
+                                          offsets,
                                           lookup->word_length,
                                           BITS_PER_NUC,
                                           lookup->lut_word_length,
                                           query, locations,
                                           lookup->hash_callback,
                                           lookup->mask,
-                                          counts);
+                                          lookup->pv);
+
     if (locations && 
         lookup->word_length > lookup->lut_word_length && 
         s_HasMaskAtHashEnabled(query_options)) {
         lookup->masked_locations = s_SeqLocListInvert(locations, query->length);
     }
-    s_BlastNaHashLookupFinalize(thin_backbone, lookup);
+    s_BlastNaHashLookupFinalize(thin_backbone, offsets, lookup);
     sfree(thin_backbone);
-    if (counts) {
-        sfree(counts);
-    }
+    sfree(offsets);
 
     return 0;
 }
