@@ -1,4 +1,4 @@
-/* $Id: blast_options.c,v 1.217 2012/04/20 12:54:33 kazimird Exp $
+/* $Id: blast_options.c,v 1.226 2016/07/01 15:49:12 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -32,19 +32,13 @@
  *
  */
 
-#ifndef SKIP_DOXYGEN_PROCESSING
-static char const rcsid[] = 
-    "$Id: blast_options.c,v 1.217 2012/04/20 12:54:33 kazimird Exp $";
-#endif /* SKIP_DOXYGEN_PROCESSING */
-
 #include <algo/blast/core/blast_options.h>
 #include <algo/blast/core/blast_filter.h>
 #include <algo/blast/core/blast_stat.h>
 #include <algo/blast/composition_adjustment/composition_constants.h>
 #include <algo/blast/core/hspfilter_collector.h>
 #include <algo/blast/core/hspfilter_besthit.h>
-
-const int kUngappedHSPNumMax = 400;  /**< Suggested max. number of HSPs for an ungapped search. */
+#include <algo/blast/core/blast_util.h>
 
 const double kPSSM_NoImpalaScaling = 1.0;
 
@@ -428,7 +422,8 @@ Int2 SBlastFilterOptionsValidate(EBlastProgramType program_number, const SBlastF
 
        if (filter_options->repeatFilterOptions)
        {
-           if (program_number != eBlastTypeBlastn)
+           if (program_number != eBlastTypeBlastn &&
+               program_number != eBlastTypeMapping)
            {
                if (blast_message)
                   Blast_MessageWrite(blast_message, eBlastSevError, kBlastMessageNoContext,
@@ -447,7 +442,8 @@ Int2 SBlastFilterOptionsValidate(EBlastProgramType program_number, const SBlastF
 
        if (filter_options->dustOptions)
        {
-           if (program_number != eBlastTypeBlastn)
+           if (program_number != eBlastTypeBlastn &&
+               program_number != eBlastTypeMapping)
            {
                if (blast_message)
                   Blast_MessageWrite(blast_message, eBlastSevError, kBlastMessageNoContext,
@@ -458,7 +454,8 @@ Int2 SBlastFilterOptionsValidate(EBlastProgramType program_number, const SBlastF
   
        if (filter_options->segOptions)
        {
-           if (program_number == eBlastTypeBlastn)
+           if (program_number == eBlastTypeBlastn &&
+               program_number != eBlastTypeMapping)
            {
                if (blast_message)
                   Blast_MessageWrite(blast_message, eBlastSevError, kBlastMessageNoContext,
@@ -515,7 +512,8 @@ Int2 BLAST_FillQuerySetUpOptions(QuerySetUpOptions* options,
    
    if (strand_option && 
        (program == eBlastTypeBlastn || program == eBlastTypePhiBlastn || 
-        program == eBlastTypeBlastx || program == eBlastTypeTblastx)) {
+        program == eBlastTypeBlastx || program == eBlastTypeTblastx ||
+        program == eBlastTypeMapping)) {
       options->strand_option = strand_option;
    }
 
@@ -551,8 +549,9 @@ BlastInitialWordOptionsNew(EBlastProgramType program,
    if (*options == NULL)
       return BLASTERR_MEMORY;
 
-   if (program != eBlastTypeBlastn &&
-       program != eBlastTypePhiBlastn) {	/* protein-protein options. */
+   if (/*program != eBlastTypeBlastn &&
+         program != eBlastTypePhiBlastn */
+       !Blast_ProgramIsNucleotide(program)) {	/* protein-protein options. */
       (*options)->window_size = BLAST_WINDOW_SIZE_PROT;
       (*options)->x_dropoff = BLAST_UNGAPPED_X_DROPOFF_PROT;
       (*options)->gap_trigger = BLAST_GAP_TRIGGER_PROT;
@@ -580,6 +579,7 @@ BlastInitialWordOptionsValidate(EBlastProgramType program_number,
    /* PHI-BLAST has no ungapped extension phase.  Megablast may not have it,
     but generally does now. */
    if (program_number != eBlastTypeBlastn  &&
+       program_number != eBlastTypeMapping &&
        (!Blast_ProgramIsPhiBlast(program_number)) &&
        options->x_dropoff <= 0.0)
    {
@@ -637,8 +637,9 @@ BlastExtensionOptionsNew(EBlastProgramType program, BlastExtensionOptions* *opti
 	if (*options == NULL)
 		return BLASTERR_MEMORY;
 
-	if (program != eBlastTypeBlastn &&
-        program != eBlastTypePhiBlastn) /* protein-protein options. */
+	if (/* program != eBlastTypeBlastn &&
+           program != eBlastTypePhiBlastn*/
+        !Blast_ProgramIsNucleotide(program)) /* protein-protein options. */
 	{
 		(*options)->gap_x_dropoff = BLAST_GAP_X_DROPOFF_PROT;
 		(*options)->gap_x_dropoff_final = 
@@ -658,6 +659,8 @@ BlastExtensionOptionsNew(EBlastProgramType program, BlastExtensionOptions* *opti
         (*options)->compositionBasedStats = eCompositionBasedStats;
     }
 
+    (*options)->max_mismatches = 5;
+    (*options)->mismatch_window = 10;
     (*options)->program_number = program;
 
 	return 0;
@@ -671,7 +674,8 @@ BLAST_FillExtensionOptions(BlastExtensionOptions* options,
    if (!options)
       return BLASTERR_INVALIDPARAM;
 
-   if (program == eBlastTypeBlastn || program == eBlastTypePhiBlastn) {
+   if (/*program == eBlastTypeBlastn || program == eBlastTypePhiBlastn*/
+       Blast_ProgramIsNucleotide(program)) {
       if (greedy) {
          options->gap_x_dropoff = BLAST_GAP_X_DROPOFF_GREEDY;
          options->gap_x_dropoff_final = BLAST_GAP_X_DROPOFF_FINAL_NUCL;
@@ -712,6 +716,7 @@ BlastExtensionOptionsValidate(EBlastProgramType program_number,
 		return  BLASTERR_INVALIDPARAM;
 
 	if (program_number != eBlastTypeBlastn &&
+        program_number != eBlastTypeMapping &&
             (options->ePrelimGapExt == eGreedyScoreOnly ||
              options->eTbackExt == eGreedyTbck))
 	{
@@ -758,8 +763,9 @@ BlastScoringOptionsNew(EBlastProgramType program_number, BlastScoringOptions* *o
    if (*options == NULL)
       return BLASTERR_INVALIDPARAM;
    
-   if (program_number != eBlastTypeBlastn &&
-       program_number != eBlastTypePhiBlastn) {	/* protein-protein options. */
+   if (/*program_number != eBlastTypeBlastn &&
+         program_number != eBlastTypePhiBlastn*/
+       !Blast_ProgramIsNucleotide(program_number)) {/*protein-protein options.*/
       (*options)->shift_pen = INT2_MAX;
       (*options)->is_ooframe = FALSE;
       (*options)->gap_open = BLAST_GAP_OPEN_PROT;
@@ -792,8 +798,9 @@ BLAST_FillScoringOptions(BlastScoringOptions* options,
    if (!options)
       return BLASTERR_INVALIDPARAM;
 
-   if (program_number != eBlastTypeBlastn &&
-       program_number != eBlastTypePhiBlastn) {	/* protein-protein options. */
+   if (/*program_number != eBlastTypeBlastn &&
+         program_number != eBlastTypePhiBlastn*/
+       !Blast_ProgramIsNucleotide(program_number)) {/* protein-protein options. */
       /* If matrix name is not provided, keep the default "BLOSUM62" value filled in 
          BlastScoringOptionsNew, otherwise reset it. */
       if (matrix)
@@ -837,7 +844,8 @@ BlastScoringOptionsValidate(EBlastProgramType program_number,
 		return BLASTERR_OPTION_PROGRAM_INVALID;
         }
 
-	if (program_number == eBlastTypeBlastn || program_number == eBlastTypePhiBlastn)
+        if (/*program_number == eBlastTypeBlastn || program_number == eBlastTypePhiBlastn*/
+            Blast_ProgramIsNucleotide(program_number))
 	{
            // A penalty/reward of 0/0 is a signal that this is rmblastn
            // which allows specification of penalties as positive integers.
@@ -850,7 +858,10 @@ BlastScoringOptionsValidate(EBlastProgramType program_number,
 			return BLASTERR_OPTION_VALUE_INVALID;
 		}
 
-                if (options->gapped_calculation && !BLAST_CheckRewardPenaltyScores(options->reward, options->penalty))
+        /* !!! this is temporary until there is jumper or mapping options handle */
+        if (0 && options->gapped_calculation &&
+            !Blast_ProgramIsMapping(program_number) &&
+            !BLAST_CheckRewardPenaltyScores(options->reward, options->penalty))
                 {
 			Blast_MessageWrite(blast_msg, eBlastSevWarning, kBlastMessageNoContext,
                             "BLASTN reward/penalty combination not supported for gapped search");
@@ -870,14 +881,19 @@ BlastScoringOptionsValidate(EBlastProgramType program_number,
                 if (options->gapped_calculation && !Blast_ProgramIsRpsBlast(program_number))
                 {
                     Int2 status=0;
+                    Boolean std_matrix_only =
+                        (program_number != eBlastTypeBlastp &&
+                         program_number != eBlastTypeTblastn);
                     if ((status=Blast_KarlinBlkGappedLoadFromTables(NULL, options->gap_open,
-                     options->gap_extend, options->matrix)) != 0)
+                          options->gap_extend, options->matrix, std_matrix_only)) != 0)
                      {
 			if (status == 1)
 			{
 				char* buffer;
 
-				buffer = BLAST_PrintMatrixMessage(options->matrix); 
+				buffer = BLAST_PrintMatrixMessage(options->matrix,
+                                                  std_matrix_only);
+
                                 Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext, buffer);
 				sfree(buffer);
 				return BLASTERR_OPTION_VALUE_INVALID;
@@ -1037,6 +1053,7 @@ LookupTableOptionsNew(EBlastProgramType program_number, LookupTableOptions* *opt
       return BLASTERR_INVALIDPARAM;
    
    switch (program_number) {
+   case eBlastTypeMapping:
    case eBlastTypeBlastn:
        /* Blastn default is megablast. */
        (*options)->word_size = BLAST_WORDSIZE_MEGABLAST;
@@ -1073,6 +1090,7 @@ LookupTableOptionsNew(EBlastProgramType program_number, LookupTableOptions* *opt
    }
 
    (*options)->program_number = program_number;
+   (*options)->stride = 0;
 
    return 0;
 }
@@ -1086,6 +1104,7 @@ BLAST_FillLookupTableOptions(LookupTableOptions* options,
       return BLASTERR_INVALIDPARAM;
 
    if (program_number == eBlastTypeBlastn) {
+
       if (is_megablast)	{
          options->lut_type = eMBLookupTable;
          options->word_size = BLAST_WORDSIZE_MEGABLAST;
@@ -1093,6 +1112,9 @@ BLAST_FillLookupTableOptions(LookupTableOptions* options,
          options->lut_type = eNaLookupTable;
          options->word_size = BLAST_WORDSIZE_NUCL;
       }
+   } else if (program_number == eBlastTypeMapping) {
+       options->lut_type = eNaHashLookupTable;
+       options->word_size = BLAST_WORDSIZE_MAPPER;
    } else {
       options->lut_type = eAaLookupTable;
    }
@@ -1123,7 +1145,8 @@ Int2 BLAST_GetSuggestedThreshold(EBlastProgramType program_number, const char* m
 
     const double kB62_threshold = 11;
 
-    if (program_number == eBlastTypeBlastn)
+    if (program_number == eBlastTypeBlastn ||
+        program_number == eBlastTypeMapping)
       return 0;
 
     if (matrixName == NULL)
@@ -1141,6 +1164,8 @@ Int2 BLAST_GetSuggestedThreshold(EBlastProgramType program_number, const char* m
         *threshold = 16;
     else if(strcasecmp(matrixName, "PAM70") == 0)
         *threshold = 14;
+    else if(strcasecmp(matrixName, "IDENTITY") == 0)
+        *threshold = 27;
     else
         *threshold = kB62_threshold;
 
@@ -1156,7 +1181,8 @@ Int2 BLAST_GetSuggestedWindowSize(EBlastProgramType program_number, const char*
 {
     const Int4 kB62_windowsize = 40;
 
-    if (program_number == eBlastTypeBlastn)
+    if (program_number == eBlastTypeBlastn ||
+        program_number == eBlastTypeMapping)
       return 0;
 
     if (matrixName == NULL)
@@ -1244,6 +1270,7 @@ LookupTableOptionsValidate(EBlastProgramType program_number,
         return 0;
 
     if (program_number != eBlastTypeBlastn && 
+        program_number != eBlastTypeMapping &&
         (!Blast_ProgramIsRpsBlast(program_number)) &&
         options->threshold <= 0)
     {
@@ -1259,12 +1286,15 @@ LookupTableOptionsValidate(EBlastProgramType program_number,
                                      "Word-size must be greater than zero");
             return BLASTERR_OPTION_VALUE_INVALID;
         }
-    } else if (program_number == eBlastTypeBlastn && options->word_size < 4)
+    } else if (/*program_number == eBlastTypeBlastn*/
+               Blast_ProgramIsNucleotide(program_number) &&
+               !Blast_QueryIsPattern(program_number) && options->word_size < 4)
     {
         Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext, 
                   "Word-size must be 4 or greater for nucleotide comparison");
         return BLASTERR_OPTION_VALUE_INVALID;
-    } else if (program_number != eBlastTypeBlastn && options->word_size > 5)
+    } else if (program_number != eBlastTypeBlastn &&
+               program_number != eBlastTypeMapping && options->word_size > 5)
     {
         if (program_number == eBlastTypeBlastp ||
             program_number == eBlastTypeTblastn ||
@@ -1287,7 +1317,8 @@ LookupTableOptionsValidate(EBlastProgramType program_number,
         }
     }
 
-    if (program_number != eBlastTypeBlastn && 
+    if (program_number != eBlastTypeBlastn &&
+        program_number != eBlastTypeMapping &&
        options->lut_type == eMBLookupTable)
     {
         Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext,
@@ -1317,7 +1348,10 @@ LookupTableOptionsValidate(EBlastProgramType program_number,
         }
     }
 
-   if (program_number == eBlastTypeBlastn && options->mb_template_length > 0) {
+    if (/*program_number == eBlastTypeBlastn &&*/
+        Blast_ProgramIsNucleotide(program_number) &&
+        !Blast_QueryIsPattern(program_number) &&
+        options->mb_template_length > 0) {
       if (!s_DiscWordOptionsValidate(options->word_size,
               options->mb_template_length, 
               options->mb_template_type,
@@ -1329,6 +1363,21 @@ LookupTableOptionsValidate(EBlastProgramType program_number,
          return BLASTERR_OPTION_VALUE_INVALID;
       } 
    }
+
+   if (!Blast_ProgramIsNucleotide(program_number) && options->db_filter) {
+       Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext,
+                          "The limit_lookup option can only be used for "
+                          "nucleotide searches");
+       return BLASTERR_OPTION_VALUE_INVALID;
+   }
+
+   if (options->db_filter && options->word_size < BLAST_WORDSIZE_MAPPER) {
+       Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext,
+                          "The limit_lookup option can only be used with "
+                          "word size >= 16");
+       return BLASTERR_OPTION_VALUE_INVALID;
+   }
+
     return 0;
 }
 
@@ -1394,10 +1443,6 @@ BLAST_FillHitSavingOptions(BlastHitSavingOptions* options,
       options->expect_value = evalue;
    if (min_diag_separation)
       options->min_diag_separation = min_diag_separation;
-   if(!is_gapped) {
-      options->hsp_num_max = kUngappedHSPNumMax;
-      options->do_sum_stats = TRUE;
-   }
    options->culling_limit = culling_limit;
    options->hsp_filt_opt = NULL;
 
@@ -1429,7 +1474,8 @@ BlastHitSavingOptionsValidate(EBlastProgramType program_number,
    if (options->longest_intron != 0 &&
        program_number != eBlastTypeTblastn &&
        program_number != eBlastTypePsiTblastn &&
-       program_number != eBlastTypeBlastx) {
+       program_number != eBlastTypeBlastx &&
+       program_number != eBlastTypeMapping) {
                 Blast_MessageWrite(blast_msg, eBlastSevError, kBlastMessageNoContext,
          "Uneven gap linking of HSPs is allowed for blastx, "
          "tblastn, and psitblastn only");
@@ -1603,31 +1649,45 @@ static Int2 s_BlastExtensionScoringOptionsValidate(EBlastProgramType program_num
     {
         if (score_options->gap_open == 0 && score_options->gap_extend == 0)
         {
-	    if (ext_options->ePrelimGapExt != eGreedyScoreOnly && 
+            if (ext_options->ePrelimGapExt != eGreedyScoreOnly && 
                 ext_options->eTbackExt != eGreedyTbck)
-	    {
-			Blast_MessageWrite(blast_msg, eBlastSevWarning, kBlastMessageNoContext,
-                            "Greedy extension must be used if gap existence and extension options are zero");
-			return BLASTERR_OPTION_VALUE_INVALID;
-	    }
-	}
+                {
+                    Blast_MessageWrite(blast_msg, eBlastSevWarning,
+                                       kBlastMessageNoContext,
+                                       "Greedy extension must be used if gap existence and extension options are zero");
+                    return BLASTERR_OPTION_VALUE_INVALID;
+                }
+        }
+    }
+
+    if (program_number == eBlastTypeMapping) {
+        if (ext_options->ePrelimGapExt != eJumperWithTraceback) {
+
+            Blast_MessageWrite(blast_msg, eBlastSevWarning,
+                               kBlastMessageNoContext,
+                               "Jumper extension must be used for mapping");
+
+            return BLASTERR_OPTION_VALUE_INVALID;
+        }
     }
 
     if (ext_options->compositionBasedStats != eNoCompositionBasedStats)
     {
-            if (!Blast_QueryIsPssm(program_number) && program_number != eBlastTypeTblastn && 
-                 program_number != eBlastTypeBlastp &&
-                 program_number != eBlastTypeBlastx &&
-                 program_number != eBlastTypePsiBlast) {
+        if (!Blast_QueryIsPssm(program_number) && program_number != eBlastTypeTblastn && 
+            program_number != eBlastTypeBlastp &&
+            program_number != eBlastTypeBlastx &&
+            program_number != eBlastTypeRpsBlast &&
+            program_number != eBlastTypeRpsTblastn &&
+            program_number != eBlastTypePsiBlast) {
 			Blast_MessageWrite(blast_msg, eBlastSevWarning, kBlastMessageNoContext,
                             "Compositional adjustments are only supported with blastp, blastx, or tblastn");
 			return BLASTERR_OPTION_VALUE_INVALID;
-            }
-            if (!score_options->gapped_calculation) {
+        }
+        if (!score_options->gapped_calculation) {
 			Blast_MessageWrite(blast_msg, eBlastSevWarning, kBlastMessageNoContext,
                             "Compositional adjustments are only supported for gapped searches");
 			return BLASTERR_OPTION_VALUE_INVALID;
-            }
+        }
             
     }
 
@@ -1664,7 +1724,28 @@ Int2 BLAST_ValidateOptions(EBlastProgramType program_number,
                                                score_options, blast_msg)) != 0)
        return status;
 
-   
+   /* Word sizes larger than 5 are not suported for IDENTITY scoring matrix.
+    Identity matrix is only supported for blastp and tblastn. */
+    if (program_number == eBlastTypeBlastp ||
+        program_number == eBlastTypeTblastn) {
+
+       char* matrix = BLAST_StrToUpper(score_options->matrix);
+       Boolean is_identity = strcmp(matrix, "IDENTITY") == 0;
+
+       if (matrix) {
+           free(matrix);
+       }
+       
+       if (lookup_options->word_size > 5 && is_identity) {
+
+           Blast_MessageWrite(blast_msg, eBlastSevError,
+                              kBlastMessageNoContext,
+                              "Word size larger than 5 is not supported for "
+                              "the identity scoring matrix");
+
+           return BLASTERR_OPTION_VALUE_INVALID;
+       }
+   }
 
    return status;
 }
@@ -1800,7 +1881,6 @@ BlastHSPFilteringOptionsValidate(const BlastHSPFilteringOptions* opts)
     if ((opts->culling_stage & ePrelimSearch) && writer_found) {
         return 1;
     }
-    writer_found = (opts->culling_stage & ePrelimSearch ? TRUE : FALSE);
 
     return retval;
 }
