@@ -1,4 +1,4 @@
-/*  $Id: blast_stat.h,v 1.96 2012/02/01 14:39:34 kazimird Exp $
+/*  $Id: blast_stat.h,v 1.98 2016/03/18 14:29:15 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -81,7 +81,7 @@ typedef struct Blast_KarlinBlk {
 */
 typedef struct erfc_table {
       double eps;
-      double a;  
+      double a;
       double b;
       Int4   N;
       double h;
@@ -108,7 +108,7 @@ typedef struct Blast_GumbelBlk {
       Int8 db_length;    /**< total length of database */
 
       Boolean filled;    /**< flag indicate the values of gbp are prepared */
-      
+
    } Blast_GumbelBlk;
 
 
@@ -175,7 +175,7 @@ SPsiBlastScoreMatrixFree(SPsiBlastScoreMatrix* matrix);
 /** Structure used for scoring calculations.
 */
 typedef struct BlastScoreBlk {
-   Boolean     protein_alphabet; /**< TRUE if alphabet_code is for a 
+   Boolean     protein_alphabet; /**< TRUE if alphabet_code is for a
 protein alphabet (e.g., ncbistdaa etc.), FALSE for nt. alphabets. */
    Uint1    alphabet_code; /**< NCBI alphabet code. */
    Int2     alphabet_size;  /**< size of alphabet. */
@@ -188,8 +188,8 @@ protein alphabet (e.g., ncbistdaa etc.), FALSE for nt. alphabets. */
                                          position specific (i.e.: PSI-BLAST) */
    Boolean  matrix_only_scoring;  /**< Score ungapped/gapped alignment only
                                        using the matrix parameters and
-                                       with raw scores. Ignore 
-                                       penalty/reward and do not report 
+                                       with raw scores. Ignore
+                                       penalty/reward and do not report
                                        Karlin-Altschul stats.  This is used
                                        by the rmblastn program. -RMH- */
    Boolean complexity_adjusted_scoring; /**< Use cross_match-like complexity
@@ -228,6 +228,24 @@ typedef struct SCompressedAlphabet {
     Uint1* compress_table;  /**< translation table (AA->compressed)*/
 } SCompressedAlphabet;
 
+/** Deallocates SBlastScoreMatrix structure
+ * @param matrix structure to deallocate [in]
+ * @return NULL
+ */
+NCBI_XBLAST_EXPORT
+SBlastScoreMatrix*
+SBlastScoreMatrixFree(SBlastScoreMatrix* matrix);
+
+/** Allocates a new SBlastScoreMatrix structure of the specified dimensions.
+ * @param ncols number of columns [in]
+ * @param nrows number of rows [in]
+ * @return NULL in case of memory allocation failure, else new
+ * SBlastScoreMatrix structure
+ */
+NCBI_XBLAST_EXPORT
+SBlastScoreMatrix*
+SBlastScoreMatrixNew(size_t ncols, size_t nrows);
+
 /** Allocate a new compressed alphabet and score matrix
  * @param sbp Current score matrix information [in]
  * @param compressed_alphabet_size Desired size of compressed
@@ -238,7 +256,7 @@ typedef struct SCompressedAlphabet {
 NCBI_XBLAST_EXPORT
 SCompressedAlphabet*
 SCompressedAlphabetNew(BlastScoreBlk *sbp,
-                       Int4 compressed_alphabet_size, 
+                       Int4 compressed_alphabet_size,
                        double scale_factor);
 
 /** Free a compressed alphabet and score matrix
@@ -249,7 +267,7 @@ NCBI_XBLAST_EXPORT
 SCompressedAlphabet*
 SCompressedAlphabetFree(SCompressedAlphabet *alphabet);
 
-/** 
+/**
 Stores the letter frequency of a sequence or database.
 */
 typedef struct Blast_ResFreq {
@@ -258,7 +276,7 @@ typedef struct Blast_ResFreq {
     double* prob0;            /**< probs, zero offset. */
 } Blast_ResFreq;
 
-/** 
+/**
  * Check that score blk is valid, returns zero if it is.
  * @param sbp ScoreBlk to check [in]
  * @return zero if valid
@@ -301,18 +319,18 @@ Int2 BLAST_ScoreSetAmbigRes (BlastScoreBlk* sbp, char ambiguous_res);
  * @param query Buffer containing (concatenated) query sequence [in]
  * @param query_info Information about offsets of concatenated queries [in]
  * @param blast_message returns queries that could not be processed [out]
- * @return 0 if ungapped Karlin-Altschul parameters could be calculated for 
- *        all of the query sequence's contexts; 1 if any of the contexts 
+ * @return 0 if ungapped Karlin-Altschul parameters could be calculated for
+ *        all of the query sequence's contexts; 1 if any of the contexts
  *        failed (but all others will be populated).
  */
 NCBI_XBLAST_EXPORT
 Int2
-Blast_ScoreBlkKbpUngappedCalc(EBlastProgramType program, 
-                              BlastScoreBlk* sbp, Uint1* query, 
+Blast_ScoreBlkKbpUngappedCalc(EBlastProgramType program,
+                              BlastScoreBlk* sbp, Uint1* query,
                               const BlastQueryInfo* query_info,
                               Blast_Message* *blast_message);
 
-/** This function fills in the BlastScoreBlk structure.  
+/** This function fills in the BlastScoreBlk structure.
  * Tasks are:
  * -read in the matrix
  * -set maxscore
@@ -322,7 +340,7 @@ Blast_ScoreBlkKbpUngappedCalc(EBlastProgramType program,
 */
 NCBI_XBLAST_EXPORT
 Int2 Blast_ScoreBlkMatrixFill (BlastScoreBlk* sbp, GET_MATRIX_PATH get_path);
- 
+
 /** Callocs a Blast_KarlinBlk
  * @return pointer to the Blast_KarlinBlk
 */
@@ -334,7 +352,7 @@ Blast_KarlinBlk* Blast_KarlinBlkNew (void);
  * @param kbp_to Karlin block to copy values to [in] [out]
  * @param kbp_from Karlin block to copy values from [in]
  * @return 0 on success; -1 if either argument is NULL on input.
- */ 
+ */
 NCBI_XBLAST_EXPORT
 Int2 Blast_KarlinBlkCopy(Blast_KarlinBlk* kbp_to, Blast_KarlinBlk* kbp_from);
 
@@ -346,7 +364,7 @@ Int2 Blast_KarlinBlkCopy(Blast_KarlinBlk* kbp_to, Blast_KarlinBlk* kbp_from);
 NCBI_XBLAST_EXPORT
 Blast_KarlinBlk* Blast_KarlinBlkFree(Blast_KarlinBlk* kbp);
 
-/** Fills in lambda, H, and K values, as calculated by Stephen Altschul 
+/** Fills in lambda, H, and K values, as calculated by Stephen Altschul
  *  in Methods in Enzy. (vol 266, page 474).
  * @param kbp object to be filled in [in|out]
  * @param gap_open cost of gap existence [in]
@@ -356,13 +374,13 @@ Blast_KarlinBlk* Blast_KarlinBlkFree(Blast_KarlinBlk* kbp);
  * @return zero on success
  */
 NCBI_XBLAST_EXPORT
-Int2 Blast_KarlinBlkGappedCalc (Blast_KarlinBlk* kbp, Int4 gap_open, 
+Int2 Blast_KarlinBlkGappedCalc (Blast_KarlinBlk* kbp, Int4 gap_open,
      Int4 gap_extend, const char* matrix_name, Blast_Message** error_return);
 
 /** Retrieves Karlin-Altschul parameters from precomputed tables, given the
- * substitution and gap scores. Gap cost values greater than any of those 
+ * substitution and gap scores. Gap cost values greater than any of those
  * listed in the tables ("greater" meaning that both values are greater than or
- * equal, and at least one is strictly greater), are treated as infinite, and 
+ * equal, and at least one is strictly greater), are treated as infinite, and
  * parameters values are copied from the ungapped Karlin block.
  * @param kbp Allocated Karlin block to fill [in] [out]
  * @param gap_open Gap openening (existence) cost [in]
@@ -376,7 +394,7 @@ Int2 Blast_KarlinBlkGappedCalc (Blast_KarlinBlk* kbp, Int4 gap_open,
  */
 NCBI_XBLAST_EXPORT
 Int2
-Blast_KarlinBlkNuclGappedCalc(Blast_KarlinBlk* kbp, Int4 gap_open, 
+Blast_KarlinBlkNuclGappedCalc(Blast_KarlinBlk* kbp, Int4 gap_open,
                               Int4 gap_extend, Int4 reward, Int4 penalty,
                               Blast_KarlinBlk* kbp_ungap,
                               Boolean* round_down,
@@ -386,7 +404,7 @@ Blast_KarlinBlkNuclGappedCalc(Blast_KarlinBlk* kbp, Int4 gap_open,
 /** Calculates the Karlin-Altschul parameters assuming standard residue
  * compositions for the query and subject sequences. It populates the kbp_ideal
  * field of its sbp argument. This is used if the query is translated and the
- * calculated (real) Karlin parameters are bad, as they're calculated for 
+ * calculated (real) Karlin parameters are bad, as they're calculated for
  * non-coding regions.
  * @param sbp ScoreBlk used to calculate "ideal" values. [in|out]
  * @return 0 on success, 1 on failure
@@ -400,12 +418,13 @@ Int2 Blast_ScoreBlkKbpIdealCalc(BlastScoreBlk* sbp);
  * @param gap_open gap existence cost [in]
  * @param gap_extend gap extension cost [in]
  * @param matrix_name name of the matrix used [in]
+ * @param standard_only If true, include only the standard blosum and pam matrices [in]
  * @return  -1 if matrix_name is NULL;
  *          1 if matrix not found
  *           2 if matrix found, but open, extend etc. values not supported.
 */
 NCBI_XBLAST_EXPORT
-Int2 Blast_KarlinBlkGappedLoadFromTables(Blast_KarlinBlk* kbp, Int4 gap_open, Int4 gap_extend, const char* matrix_name);
+Int2 Blast_KarlinBlkGappedLoadFromTables(Blast_KarlinBlk* kbp, Int4 gap_open, Int4 gap_extend, const char* matrix_name, Boolean standard_only);
 
 /** Fills in gumbel parameters to estimate p-value using FSC
  * @param gbp object to be filled in [in|out]
@@ -416,7 +435,7 @@ Int2 Blast_KarlinBlkGappedLoadFromTables(Blast_KarlinBlk* kbp, Int4 gap_open, In
  * @return zero on success
  */
 NCBI_XBLAST_EXPORT
-Int2 Blast_GumbelBlkCalc (Blast_GumbelBlk* gbp, Int4 gap_open, 
+Int2 Blast_GumbelBlkCalc (Blast_GumbelBlk* gbp, Int4 gap_open,
      Int4 gap_extend, const char* matrix_name, Blast_Message** error_return);
 
 /** Attempts to fill GumbelBlk for given gap opening, extensions etc.
@@ -430,18 +449,20 @@ Int2 Blast_GumbelBlkCalc (Blast_GumbelBlk* gbp, Int4 gap_open,
  *           2 if matrix found, but open, extend etc. values not supported.
 */
 NCBI_XBLAST_EXPORT
-Int2 Blast_GumbelBlkLoadFromTables(Blast_GumbelBlk* gbp, Int4 gap_open, 
+Int2 Blast_GumbelBlkLoadFromTables(Blast_GumbelBlk* gbp, Int4 gap_open,
      Int4 gap_extend, const char* matrix_name);
 
-/** Prints a messages about the allowed matrices, BlastKarlinBlkGappedFill should return 1 before this is called. 
+/** Prints a messages about the allowed matrices, BlastKarlinBlkGappedFill should return 1 before this is called.
  * @param matrix the matrix to print a message about [in]
+ * @param standard_only, If true, include only the standad blosum and pam
+ * matrices [in]
  * @return the message
  */
 NCBI_XBLAST_EXPORT
-char* BLAST_PrintMatrixMessage(const char *matrix);
+char* BLAST_PrintMatrixMessage(const char *matrix, Boolean standard_only);
 
-/** Prints a messages about the allowed open etc values for the given matrix, 
- * BlastKarlinBlkGappedFill should return 2 before this is called. 
+/** Prints a messages about the allowed open etc values for the given matrix,
+ * BlastKarlinBlkGappedFill should return 2 before this is called.
  * @param matrix name of the matrix [in]
  * @param gap_open gap existence cost [in]
  * @param gap_extend cost to extend a gap by one [in]
@@ -455,7 +476,7 @@ NCBI_XBLAST_EXPORT
 double
 Blast_KarlinLambdaNR(Blast_ScoreFreq* sfp, double initialLambdaGuess);
 
-/** Calculates the Expect value based upon the search space and some Karlin-Altschul 
+/** Calculates the Expect value based upon the search space and some Karlin-Altschul
  * parameters.  It is "simple" as it does not use sum-statistics.
  * @param S the score of the alignment. [in]
  * @param kbp the Karlin-Altschul parameters. [in]
@@ -492,20 +513,20 @@ Int4 BLAST_SpougeEtoS (double E, Blast_KarlinBlk* kbp, Blast_GumbelBlk* gbp, Int
  * If given a database P-value, this routine will return a database
  * E-value; if given a pairwise P-value, it will return a pairwise
  * E-value.
- *  
+ *
  * In the context of a database search, the available P-value is often
  * a pairwise P-value, whereas the desired E-value is a database
  * E-value.  When this it the case, the value returned by this routine
  * should be multiplied by the effective length of the database and
  * divided by the effective length of the subject.
- * 
+ *
  * @param p the P-value to be converted [in] @return the corresponding
  * expect value.
  */
 NCBI_XBLAST_EXPORT double BLAST_KarlinPtoE(double p);
 
 /** Convert an E-value to a P-value.
- * 
+ *
  * E-values and P-values may either represent statistics of a database
  * search or represent statistics on the two sequences being compared.
  * If given a database E-value, this routine will return a database
@@ -553,7 +574,7 @@ double BLAST_GapDecayDivisor(double decayrate, unsigned nsegs );
  * @param gap_decay_rate Gap decay rate to use, if dodecay is set [in]
  */
 NCBI_XBLAST_EXPORT
-Int2 BLAST_Cutoffs (Int4 *S, double* E, Blast_KarlinBlk* kbp, 
+Int2 BLAST_Cutoffs (Int4 *S, double* E, Blast_KarlinBlk* kbp,
                     Int8 searchsp, Boolean dodecay, double gap_decay_rate);
 
 /** Calculates the e-value for alignments with "small" gaps (typically
@@ -567,9 +588,9 @@ Int2 BLAST_Cutoffs (Int4 *S, double* E, Blast_KarlinBlk* kbp,
  * @param subject_length effective len of the subject seq [in]
  * @param searchsp_eff effective size of the search space [in]
  * @param weight_divisor a divisor used to weight the e-value
- *    when multiple collections of alignments are being considered by 
+ *    when multiple collections of alignments are being considered by
  *    the calling routine [in]
- * @return the expect value 
+ * @return the expect value
  */
 NCBI_XBLAST_EXPORT
 double BLAST_SmallGapSumE (Int4 start_points, Int2 num,  double xsum,
@@ -624,11 +645,11 @@ double BLAST_LargeGapSumE (Int2 num,  double xsum,
                            Int8 searchsp_eff, double weight_divisor );
 
 /** Extract the recommended gap existence and extension values.
- * Only to be used with protein matrices. 
+ * Only to be used with protein matrices.
  * @param  matrixName name of the matrix [in]
  * @param gap_existence returns recommended existence cost [in|out]
  * @param gap_extension returns recommended extension cost [in|out]
- * @return zero on success 
+ * @return zero on success
  */
 NCBI_XBLAST_EXPORT
 Int2 BLAST_GetProteinGapExistenceExtendParams(const char* matrixName,
@@ -641,7 +662,7 @@ Int2 BLAST_GetProteinGapExistenceExtendParams(const char* matrixName,
  * @param penalty mismatch score [in]
  * @param gap_existence returns recommended existence cost [in|out]
  * @param gap_extension returns recommended extension cost [in|out]
- * @return zero on success 
+ * @return zero on success
  */
 NCBI_XBLAST_EXPORT
 Int2 BLAST_GetNucleotideGapExistenceExtendParams(Int4 reward,
@@ -653,7 +674,7 @@ Int2 BLAST_GetNucleotideGapExistenceExtendParams(Int4 reward,
  * Only to be used with blastn searches.
  * @param reward match score [in]
  * @param penalty mismatch score [in]
- * @return TRUE on success 
+ * @return TRUE on success
  */
 NCBI_XBLAST_EXPORT
 Boolean BLAST_CheckRewardPenaltyScores(Int4 reward, Int4 penalty);
@@ -670,10 +691,10 @@ Boolean BLAST_CheckRewardPenaltyScores(Int4 reward, Int4 penalty);
 */
 NCBI_XBLAST_EXPORT
 void BLAST_GetAlphaBeta (const char* matrixName, double *alpha,
-                         double *beta, Boolean gapped, Int4 gap_open, 
+                         double *beta, Boolean gapped, Int4 gap_open,
                          Int4 gap_extend, const Blast_KarlinBlk* kbp_ungapped);
 
-/** Extract the alpha and beta settings for these substitution and gap scores. 
+/** Extract the alpha and beta settings for these substitution and gap scores.
  * If substitution or gap costs are not found in the tables, assume an ungapped
  * search. Then alpha is computed using the formula Alpha = Lambda/H, and beta
  * is equal to 0 except for some special cases.
@@ -681,25 +702,25 @@ void BLAST_GetAlphaBeta (const char* matrixName, double *alpha,
  * @param penalty Mismatch penalty score [in]
  * @param gap_open Gap opening (existence) cost [in]
  * @param gap_extend Gap extension cost [in]
- * @param kbp Karlin block containing already computed Lambda, K and H 
+ * @param kbp Karlin block containing already computed Lambda, K and H
  *            parameters.
  * @param gapped_calculation Is this a gapped search? [in]
  * @param alpha Alpha parameter for this scoring system [out]
  * @param beta Beta parameter for this scoring system [out]
  */
 NCBI_XBLAST_EXPORT
-Int2 Blast_GetNuclAlphaBeta(Int4 reward, Int4 penalty, Int4 gap_open, 
+Int2 Blast_GetNuclAlphaBeta(Int4 reward, Int4 penalty, Int4 gap_open,
                             Int4 gap_extend, Blast_KarlinBlk* kbp,
                             Boolean gapped_calculation,
                             double *alpha, double *beta);
 
 /** Rescale the PSSM, using composition-based statistics, for use
  *  with RPS BLAST. This function produces a PSSM for a single RPS DB
- *  sequence (of size db_seq_length) and incorporates information from 
+ *  sequence (of size db_seq_length) and incorporates information from
  *  the RPS blast query. Each individual database sequence must call this
  *  function to retrieve its own PSSM. The matrix is returned (and must
- *  be freed elsewhere). posMatrix is the portion of the complete 
- *  concatenated PSSM that is specific to this DB sequence 
+ *  be freed elsewhere). posMatrix is the portion of the complete
+ *  concatenated PSSM that is specific to this DB sequence
  * @todo revise to use existing code
  * @param scalingFactor used to rescale Lambda [in]
  * @param rps_query_length length of query sequence [in]
@@ -707,41 +728,41 @@ Int2 Blast_GetNuclAlphaBeta(Int4 reward, Int4 penalty, Int4 gap_open,
  * @param db_seq_length Length of the database sequence [in]
  * @param posMatrix matrix (actual) values to be used [in]
  * @param sbp Structure with score matrix parameters [in][out]
- * @return rescaled pssm 
+ * @return rescaled pssm
  */
 NCBI_XBLAST_EXPORT
-Int4 ** RPSRescalePssm(double scalingFactor, Int4 rps_query_length, 
-                   const Uint1 * rps_query_seq, Int4 db_seq_length, 
+Int4 ** RPSRescalePssm(double scalingFactor, Int4 rps_query_length,
+                   const Uint1 * rps_query_seq, Int4 db_seq_length,
                    Int4 **posMatrix, BlastScoreBlk *sbp);
 
 
-/** 
+/**
  * Computes the adjustment to the lengths of the query and database sequences
- * that is used to compensate for edge effects when computing evalues. 
+ * that is used to compensate for edge effects when computing evalues.
  *
  * The length adjustment is an integer-valued approximation to the fixed
  * point of the function
  *
- *    f(ell) = beta + 
+ *    f(ell) = beta +
  *               (alpha/lambda) * (log K + log((m - ell)*(n - N ell)))
  *
  * where m is the query length n is the length of the database and N is the
  * number of sequences in the database. The values beta, alpha, lambda and
  * K are statistical, Karlin-Altschul parameters.
- * 
- * The value of the length adjustment computed by this routine, A, 
+ *
+ * The value of the length adjustment computed by this routine, A,
  * will always be an integer smaller than the fixed point of
  * f(ell). Usually, it will be the largest such integer.  However, the
- * computed length adjustment, A, will also be so small that 
+ * computed length adjustment, A, will also be so small that
  *
  *    K * (m - A) * (n - N * A) > MAX(m,n).
  *
  * Moreover, an iterative method is used to compute A, and under
- * unusual circumstances the iterative method may not converge. 
+ * unusual circumstances the iterative method may not converge.
  *
  * @param K      the statistical parameter K [in]
  * @param logK   the natural logarithm of K [in]
- * @param alpha_d_lambda    the ratio of the statistical parameters 
+ * @param alpha_d_lambda    the ratio of the statistical parameters
  *                          alpha and lambda (for ungapped alignments, the
  *                          value 1/H should be used) [in]
  * @param beta              the statistical parameter beta (for ungapped
@@ -798,7 +819,7 @@ NCBI_XBLAST_EXPORT
 Blast_ScoreFreq*
 Blast_ScoreFreqNew(Int4 score_min, Int4 score_max);
 
-/** Deallocates the score frequencies structure 
+/** Deallocates the score frequencies structure
  * @param sfp the structure to deallocate [in]
  * @return NULL
  */
@@ -806,7 +827,7 @@ NCBI_XBLAST_EXPORT
 Blast_ScoreFreq*
 Blast_ScoreFreqFree(Blast_ScoreFreq* sfp);
 
-/** Fills a buffer with the 'standard' alphabet 
+/** Fills a buffer with the 'standard' alphabet
  * (given by STD_AMINO_ACID_FREQS[index].ch).
  *
  * @param alphabet_code specifies alphabet [in]
@@ -816,7 +837,7 @@ Blast_ScoreFreqFree(Blast_ScoreFreq* sfp);
  */
 NCBI_XBLAST_EXPORT
 Int2
-Blast_GetStdAlphabet(Uint1 alphabet_code, Uint1* residues, 
+Blast_GetStdAlphabet(Uint1 alphabet_code, Uint1* residues,
                      Uint4 residue_size);
 
 /** Computes the parameters lambda, H K for use in calculating the
@@ -854,13 +875,13 @@ Blast_FillResidueProbability(const Uint1* sequence, Int4 length, double * resPro
 NCBI_XBLAST_EXPORT
 Int2 BlastScoreBlkNuclMatrixCreate(BlastScoreBlk* sbp);
 
-/** Returns a pointer to the static compiled in version of the 
+/** Returns a pointer to the static compiled in version of the
  * matrix.  If name is NULL or the matrix is not compiled in
  * NULL is returned.
  * @param name matrix name [in]
  * @return pointer to matrix or NULL if not supported.
  */
-NCBI_XBLAST_EXPORT 
+NCBI_XBLAST_EXPORT
 SNCBIPackedScoreMatrix* BlastScoreBlkGetCompiledInMatrix(const char* name);
 
 #ifdef __cplusplus
