@@ -1,4 +1,4 @@
-/* $Id: gapinfo.c,v 1.18 2006/02/15 15:06:00 madden Exp $
+/* $Id: gapinfo.c,v 1.20 2016/05/04 14:59:32 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -32,11 +32,7 @@
  */
 
 
-#ifndef SKIP_DOXYGEN_PROCESSING
-static char const rcsid[] = 
-    "$Id: gapinfo.c,v 1.18 2006/02/15 15:06:00 madden Exp $";
-#endif /* SKIP_DOXYGEN_PROCESSING */
-
+#include <algo/blast/core/blast_def.h>
 #include <algo/blast/core/gapinfo.h>
 
 GapStateArrayStruct* 
