@@ -1,5 +1,5 @@
 
-/* $Id: link_hsps.c,v 1.73 2011/06/13 17:34:31 kazimird Exp $
+/* $Id: link_hsps.c,v 1.76 2016/05/04 14:59:32 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -32,11 +32,6 @@
  * Functions to link with use of sum statistics
  */
 
-#ifndef SKIP_DOXYGEN_PROCESSING
-static char const rcsid[] = 
-    "$Id: link_hsps.c,v 1.73 2011/06/13 17:34:31 kazimird Exp $";
-#endif /* SKIP_DOXYGEN_PROCESSING */
-
 #include <algo/blast/core/link_hsps.h>
 #include <algo/blast/core/blast_util.h>
 #include "blast_hits_priv.h"
@@ -1245,7 +1240,7 @@ s_SumScoreCompareLinkedHSPSets(const void* v1, const void* v2)
  */
 static Int4 
 s_HSPOffsetBinarySearch(BlastLinkedHSPSet** hsp_array, Int4 size, 
-                        Int4 queryId, Int4 offset)
+                        Uint4 queryId, Int4 offset)
 {
    Int4 index, begin, end;
    
@@ -1283,7 +1278,7 @@ s_HSPOffsetBinarySearch(BlastLinkedHSPSet** hsp_array, Int4 size,
  */
 static Int4 
 s_HSPOffsetEndBinarySearch(BlastLinkedHSPSet** hsp_array, Int4 size, 
-                           Int4* qend_index_array, Int4 queryId, Int4 offset)
+                           Int4* qend_index_array, Uint4 queryId, Int4 offset)
 {
    Int4 begin, end;
    
@@ -1793,7 +1788,7 @@ BLAST_LinkHsps(EBlastProgramType program_number, BlastHSPList* hsp_list,
            compare with sum e-values. Use decay rate to compensate for 
            multiple tests. */
         
-        Blast_HSPListGetEvalues(query_info, 
+        Blast_HSPListGetEvalues(program_number, query_info, 
                                 Blast_SubjectIsTranslated(program_number) ?
                                 subject_length / CODON_LENGTH : subject_length,
                                 hsp_list, gapped_calculation, FALSE,sbp, 
