@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   7/15/95
 *
-* $Revision: 6.6 $
+* $Revision: 6.13 $
 *
 * File Description: 
 *
@@ -45,6 +45,27 @@
 /*************************************
 *
  * $Log: asn2ff5.c,v $
+ * Revision 6.13  2002/01/29 12:37:21  kans
+ * restored year for unpublished records to minimize QA diffs
+ *
+ * Revision 6.12  2002/01/10 15:19:16  kans
+ * suppress year in unpublished citgen - this is new policy, and suppresses diffs against asn2gb
+ *
+ * Revision 6.11  2001/06/25 22:39:05  kans
+ * format_patent puts patent seqid in GenPept format
+ *
+ * Revision 6.10  2000/05/15 23:13:35  kans
+ * format_thesis forgot to add space for afp->affil
+ *
+ * Revision 6.9  1998/12/09 18:45:09  tatiana
+ * a bug fixed in GetAuthors()
+ *
+ * Revision 6.8  1998/06/17 21:41:24  tatiana
+ * Null pointer protection added to ValidatePub()
+ *
+ * Revision 6.7  1998/06/15 14:58:53  tatiana
+ * UNIX compiler warnings fixed
+ *
  * Revision 6.6  1998/04/30 21:49:03  tatiana
  * *** empty log message ***
  *
@@ -164,7 +185,7 @@
 *	PROTOTYPES, mostly for functions from Karl Sirotkin's code.
 *
 *************************************************************************/
-static CharPtr GetSubmitterName PROTO ((Uint1 format, ValNodePtr pub));
+static CharPtr /*UNUSED*/GetSubmitterName PROTO ((Uint1 format, ValNodePtr pub));
 NLM_EXTERN CharPtr FlatStringGroupTerm PROTO ((Boolean embl_format, CharPtr start, ValNodePtr head, CharPtr delimit, CharPtr period, CharPtr term));
 NLM_EXTERN Int2 fix_pages PROTO ((CharPtr out_pages, CharPtr in_pages));
 NLM_EXTERN CharPtr FlatDateFromCreate PROTO ((CharPtr default_date, NCBI_DatePtr flat_date));
@@ -192,7 +213,7 @@ NLM_EXTERN CharPtr format_book PROTO ((Uint1 format, ValNodePtr the_pub, Boolean
 NLM_EXTERN ValNodePtr GetAuthors (Asn2ffJobPtr ajp, ValNodePtr the_pub)
 {
 
-	AuthListPtr ap;
+	AuthListPtr ap = NULL;
 	CharPtr tmp;
 	CitArtPtr ca;
 	CitBookPtr cb;
@@ -220,7 +241,7 @@ NLM_EXTERN ValNodePtr GetAuthors (Asn2ffJobPtr ajp, ValNodePtr the_pub)
 		if ( the_pub -> choice == PUB_Medline){
 			ml = (MedlineEntryPtr) the_pub -> data.ptrvalue;
 			ca = (CitArtPtr) ml -> cit;
-		}else{
+		} else{
 			ca = (CitArtPtr) the_pub -> data.ptrvalue;
 		}
 		ap = ca -> authors;
@@ -241,31 +262,26 @@ NLM_EXTERN ValNodePtr GetAuthors (Asn2ffJobPtr ajp, ValNodePtr the_pub)
 		break;
 	}
 
-	if (ap){
+	if (ap) {
 		if (ap->choice != 1){   /* just strings */
 			for (spare = ap->names, namehead = NULL; 
-					spare; spare = spare -> next){
+					spare; spare = spare -> next) {
 				this_name = ValNodeNew(namehead);
 				if (namehead == NULL)
 					namehead = this_name;
 				this_name -> data.ptrvalue = StringSave(spare -> data.ptrvalue);
 				if (ajp->format == EMBL_FMT || ajp->format == PSEUDOEMBL_FMT ||
-					ajp->format == EMBLPEPT_FMT)
-				{
+					ajp->format == EMBLPEPT_FMT) {
 					for (tmp=(CharPtr) this_name->data.ptrvalue; 
-						*tmp != '\0'; tmp++)
-					{
-						if (*tmp == ',')
-						{
+						*tmp != '\0'; tmp++) {
+						if (*tmp == ',') {
 							*tmp = ' ';
 							break;
 						}
 					}
 				}
 			}
-		} 
-		else                  /* structured names */
-		{
+		}  else {               /* structured names */
 			namehead = GBGetAuthNames(ajp->format, ap);
 		}
 	}
@@ -508,6 +524,14 @@ NLM_EXTERN ValNodePtr GBGetAuthNames (Uint1 format, AuthListPtr ap)
 *
 *****************************************************************************/
 
+/*______________________________________________________________________
+**
+**	This code is not currently used.
+**	I do not remove this piece of code, just comment it out.
+**	-- Dmitri Lukyanov
+*/
+#if 0
+
 static CharPtr GetSubmitterName (Uint1 format, ValNodePtr pub)
 
 {
@@ -656,6 +680,10 @@ static CharPtr GetSubmitterName (Uint1 format, ValNodePtr pub)
 	return submitter_name;
 }
 
+#endif
+/*______________________________________________________________________
+*/
+
 static Boolean all_caps(CharPtr p)
 {
 	for ( p++; p != NULL && *p != '\0'; p++){
@@ -895,7 +923,7 @@ static CharPtr format_cit_sub (Uint1 format, ValNodePtr the_pub, Boolean PNTR su
 {
   AffilPtr afp = NULL;
   AuthListPtr alp;
-  Boolean need_comma = FALSE, need_space = TRUE;
+  Boolean need_comma = FALSE, /*UNUSED*/need_space = TRUE;
   Char ch;
   CitSubPtr cs;
   CharPtr affil=NULL, start, retval = NULL, temp, dup_pages = NULL;
@@ -1085,8 +1113,10 @@ static CharPtr format_patent (Uint1 format, ValNodePtr the_pub, Int4 pat_seqid,
 	if (pat_seqid > 0) {
 		if (embl_format) {
 			sprintf(buf,"%s%ld%s", "/", (long) pat_seqid, ", ");
+		/*
 		} else if (format == GENPEPT_FMT) {
 			sprintf(buf,"%s", " ? ");
+		*/
 		} else {
 			sprintf(buf,"%s%ld ", " ", (long) pat_seqid);
 		}
@@ -1174,14 +1204,13 @@ static CharPtr format_thesis (Uint1 format, ValNodePtr the_pub, Boolean make_ind
 
 {
 	AffilPtr afp;
-	AuthListPtr ap = NULL;
 	char year[5];
 	CitBookPtr cb;
 	CharPtr retval = NULL, temp;
 	DatePtr dp;
 	ImprintPtr ip;
 	int aflen=0;
-	Boolean embl_format = FALSE;
+	Boolean /*UNUSED*/embl_format = FALSE;
 	Boolean first_std=TRUE;
 
 	if (format == EMBL_FMT || format == PSEUDOEMBL_FMT ||
@@ -1209,6 +1238,7 @@ static CharPtr format_thesis (Uint1 format, ValNodePtr the_pub, Boolean make_ind
 				}
 
 			} else if (afp->choice == 2){
+				aflen += 3 + StringLen(afp -> affil);
 				aflen += 3 + StringLen(afp -> div);
 				aflen += 3 + StringLen(afp -> street);
 				aflen += 3 + StringLen(afp -> city);
@@ -1557,7 +1587,7 @@ NLM_EXTERN CharPtr format_jourarticle(Asn2ffJobPtr ajp, BioseqPtr bsp, ValNodePt
 
 
 {
-	Boolean do_unpub=FALSE, found_paran=FALSE;
+	Boolean found_paran=FALSE;
 	char year[5];
 	CharPtr temp, dup_pages=NULL, retval=NULL, volume=NULL;
 	CharPtr issue=NULL, part_sup=NULL, part_supi=NULL;
@@ -1565,7 +1595,7 @@ NLM_EXTERN CharPtr format_jourarticle(Asn2ffJobPtr ajp, BioseqPtr bsp, ValNodePt
 	CitJourPtr jp;
 	DatePtr dp;
 	ImprintPtr ip;
-	Int2 fix_p_ret, length, vol_len=0;
+	Int2 fix_p_ret, length;
 	MedlineEntryPtr ml;
 	size_t len_page = 0;
 	Boolean embl_format = FALSE;
@@ -1889,6 +1919,13 @@ static CharPtr fmt_gen_2 (Boolean embl_format, ValNodePtr the_pub,
 
   	if (year[0] != '\0') 
   	{
+  		/* this removes the year from unpublished records
+  		if (unp == NULL) {
+  			temp = StringMove (temp," (");
+  			temp = StringMove (temp, year);
+  			temp = StringMove (temp,")");
+  		}
+  		*/
   		temp = StringMove (temp," (");
   		temp = StringMove (temp, year);
   		temp = StringMove (temp,")");
@@ -2817,21 +2854,21 @@ take it and keep looking. */
 
 NLM_EXTERN Int2 ValidatePub (BioseqPtr bsp, ValNodePtr the_pub)
 {
-	AuthListPtr ap;
-	AuthorPtr authptr;
-	Boolean ignore_this=FALSE;
-	CitBookPtr cb;
-	CitSubPtr cs;
-	CitGenPtr cg;	
-	CitArtPtr ca;
-	CitPatPtr cp;
-	Int2 length, status = -1;
-	Int4 pat;
+	AuthListPtr		ap;
+	AuthorPtr		authptr;
+	Boolean			ignore_this=FALSE;
+	CitBookPtr		cb;
+	CitSubPtr		cs;
+	CitGenPtr		cg;	
+	CitArtPtr		ca;
+	CitPatPtr		cp;
+	Int2 			length, status = -1;
+	Int4			pat;
 	MedlineEntryPtr ml;
-	CitJourPtr jp;
-	ImprintPtr ip;
-	NameStdPtr nsp;
-	PersonIdPtr pid;
+	CitJourPtr		jp;
+	ImprintPtr		ip;
+	NameStdPtr		nsp;
+	PersonIdPtr		pid;
 
 	switch ( the_pub -> choice) {
 
@@ -2843,7 +2880,7 @@ NLM_EXTERN Int2 ValidatePub (BioseqPtr bsp, ValNodePtr the_pub)
 		case PUB_Man:
 		case PUB_Book: 
 			cb = (CitBookPtr) the_pub -> data.ptrvalue;
-			if ( cb -> imp){
+			if ( cb -> imp) {
 				ip = cb -> imp;
 				if (ip)
 					status = 1;
@@ -2866,7 +2903,7 @@ NLM_EXTERN Int2 ValidatePub (BioseqPtr bsp, ValNodePtr the_pub)
 			} else {
 				ca = (CitArtPtr) the_pub -> data.ptrvalue;
 			}
-		if ( ca -> fromptr){
+		if ( ca -> fromptr) {
 			if ( ca -> from ==1) {
 				jp = (CitJourPtr) ca -> fromptr;
 				if (StringLen((CharPtr)jp->title->data.ptrvalue) == 0) {
@@ -2922,10 +2959,12 @@ NLM_EXTERN Int2 ValidatePub (BioseqPtr bsp, ValNodePtr the_pub)
 
 	if (ap && the_pub -> choice != PUB_Patent) {
 		if (ap->choice == 1) {
+			if (ap->names == NULL) {
+				return -2;
+			}
 			authptr = (AuthorPtr) (ap->names)->data.ptrvalue;
 			pid = authptr->name;
-			if (pid->choice == 2)
-			{
+			if (pid->choice == 2) {
 				nsp = (NameStdPtr) pid->data;
 				length = StringLen(nsp->names[0]);
 				length += StringLen(nsp->names[3]);
@@ -2963,7 +3002,7 @@ NLM_EXTERN Int2 ValidatePub (BioseqPtr bsp, ValNodePtr the_pub)
 NLM_EXTERN void PostARefErrMessage (Asn2ffJobPtr ajp, BioseqPtr bsp, PubStructPtr psp, ValNodePtr ext_pub, Int2 status, CharPtr ext_string)
 
 {
-	Boolean ignore_this, submit=FALSE, error;
+	Boolean /*UNUSED*/ignore_this, submit=FALSE, error;
 	CharPtr authors=NULL, string=NULL, newstring=NULL, title=NULL, journal=NULL, ptr;
 	Char buffer[30];
 	Int2 length;
