@@ -1,4 +1,4 @@
-/* $Id: test_ncbi_connutil_misc.c,v 6.49 2014/11/11 14:26:15 kazimird Exp $
+/* $Id: test_ncbi_connutil_misc.c,v 6.50 2016/09/15 03:59:21 fukanchi Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -252,6 +252,8 @@ static void TEST_ConnNetInfo(void)
     assert(ConnNetInfo_ParseURL(net_info,
                                 "ftp://user:pass@host:8888/ro.t/p@th"
                                 "?arg/arg:arg@arg:arg/arg"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(net_info->scheme                           == eURL_Ftp);
     assert(strcmp(net_info->user, "user")                    == 0);
     assert(strcmp(net_info->pass, "pass")                    == 0);
@@ -261,6 +263,8 @@ static void TEST_ConnNetInfo(void)
 
     assert(ConnNetInfo_ParseURL(net_info, "https://www/path"
                                 "?arg:arg@arg#frag"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(       net_info->scheme            == eURL_Https);
     assert(      *net_info->user                       == 0);
     assert(      *net_info->pass                       == 0);
@@ -270,52 +274,75 @@ static void TEST_ConnNetInfo(void)
     assert(strcmp(net_info->args, "arg:arg@arg#frag")  == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "/path1?arg1#frag2"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->args, "arg1#frag2")        == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "path0/0"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->path, "/path0/0")          == 0);
     assert(strcmp(net_info->args, "#frag2")            == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "#frag3"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->path, "/path0/0")          == 0);
     assert(strcmp(net_info->args, "#frag3")            == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "path2"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->path, "/path0/path2")      == 0);
     assert(strcmp(net_info->args, "#frag3")            == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "/path3?arg3"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->path, "/path3")            == 0);
     assert(strcmp(net_info->args, "arg3#frag3")        == 0);
 
     strcpy(net_info->user, "user");
     strcpy(net_info->pass, "pass");
 
-    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
-
     str = ConnNetInfo_URL(net_info);
     assert(str);
     assert(strcmp(str, "https://www/path3?arg3#frag3") == 0);
     free(str);
 
     assert(ConnNetInfo_ParseURL(net_info, "path4/path5?arg4#"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     assert(strcmp(net_info->user, "user")              == 0);
     assert(strcmp(net_info->pass, "pass")              == 0);
     assert(strcmp(net_info->path, "/path4/path5")      == 0);
     assert(strcmp(net_info->args, "arg4")              == 0);
 
     assert(ConnNetInfo_ParseURL(net_info, "../path6?args"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
+    assert(strcmp(net_info->user, "user")              == 0);
+    assert(strcmp(net_info->pass, "pass")              == 0);
     assert(strcmp(net_info->path, "/path4/../path6")   == 0);
     assert(strcmp(net_info->args, "args")              == 0);
 
-    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
-
     str = ConnNetInfo_URL(net_info);
     assert(str);
     assert(strcmp(str, "https://www/path4/../path6?args") == 0);
     free(str);
 
+    assert(ConnNetInfo_ParseURL(net_info, "http:///path7?newargs"));
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
+    assert(net_info->scheme                    == eURL_Http);
+    assert(strcmp(net_info->user, "user")              == 0);
+    assert(strcmp(net_info->pass, "pass")              == 0);
+    assert(strcmp(net_info->path, "/path7")            == 0);
+    assert(strcmp(net_info->args, "newargs")           == 0);
+
     ConnNetInfo_SetUserHeader(net_info, "");
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     printf("HTTP User Header after set:\n%s%s%s\n",
            &"\""[!str], str ? buf : "NULL", &"\""[!str]);
@@ -328,6 +355,8 @@ static void TEST_ConnNetInfo(void)
                                  "T3: V3\n"
                                  "T4: V4\n"
                                  "T1: V6");
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -349,6 +378,8 @@ static void TEST_ConnNetInfo(void)
                                    "T3:V3\r\n"
                                    "T6: V6\r\n"
                                    "T4: W4 X4 Z4");
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -369,6 +400,8 @@ static void TEST_ConnNetInfo(void)
                                  "T3: T3:V3\n"
                                  "T4: X4\n"
                                  "T5");
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -388,6 +421,8 @@ static void TEST_ConnNetInfo(void)
                                  "T3: V3\r\n"
                                  "T4:X4\r\n"
                                  "T4: Z4");
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -404,6 +439,8 @@ static void TEST_ConnNetInfo(void)
 
     ConnNetInfo_DeleteUserHeader(net_info,
                                  net_info->http_user_header);
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -412,6 +449,8 @@ static void TEST_ConnNetInfo(void)
     assert(strcmp(net_info->http_user_header, "") == 0);
 
     ConnNetInfo_SetUserHeader(net_info, 0);
+    ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
+
     str = UTIL_PrintableString(net_info->http_user_header, 0, buf, 0);
     if (str)
         *str = '\0';
@@ -449,7 +488,6 @@ static void TEST_ConnNetInfo(void)
     printf("HTTP Arg after delete-all: \"%s\"\n", net_info->args);
 
     ConnNetInfo_Log(net_info, eLOG_Note, CORE_GetLOG());
-
     ConnNetInfo_Destroy(net_info);
 
     CORE_LOG(eLOG_Note, "ConnNetInfo test completed");
