@@ -19,6 +19,7 @@
 * ==========================================================================
 */
 
+#include <vibrant.h>
 #include <glbpic.h>
 #include <fstyle.h>
 #include <lsqfetch.h>
@@ -446,6 +447,7 @@ static Boolean GlobalDataNew(BioseqPtr bsp, Uint1 map_type, Boolean show_map_uni
 	g_bsp->g_marks = NULL;
 	g_bsp->cyto_marks = NULL;
 	g_bsp->priority = priority;
+	g_bsp->num_lod_score = GetLODScoreNumber (bsp);
 	if(priority == SEQINDEX_VAL)
 		g_bsp->is_seqindex_map = TRUE;
 	if(check_cyto)
@@ -544,7 +546,6 @@ static ValNodePtr layout_one_alignment_view(ValNodePtr arp_list,
 	Int4Ptr y_pos;
 	AlignRegionPtr arp;
 	Int4 t_left, t_right;
-	FloatHi min_score, max_score;
 	ValNodePtr line_data = NULL;
 
 	if(arp_list == NULL)
@@ -1012,7 +1013,7 @@ static Boolean LayoutLinearDrawing(ValNodePtr g_bsp_list, Int2 pan_width, Int2 p
 	Int2 top, bottom, left, right, c_right;
 	GlobalBspPtr gbp;
 	ValNodePtr curr;
-	Int2 num;
+	Int2 num, lod_num;
 	Int4 maxlen, max_label_len;
 	Int2 box_height;
 	Int2 maxHeight;
@@ -1026,11 +1027,15 @@ static Boolean LayoutLinearDrawing(ValNodePtr g_bsp_list, Int2 pan_width, Int2 p
 
 	/*calculate the number of sequences*/
 	num = 0;
+	lod_num = 0;
 	for(curr = g_bsp_list; curr != NULL; curr = curr->next)
 	{
 		gbp = curr->data.ptrvalue;
 		if(gbp->hide == FALSE)
+		{
 			++num;
+			lod_num += (gbp->num_lod_score);
+		}
 	}
 	if(num == 0)
 		return FALSE;
@@ -1040,7 +1045,7 @@ static Boolean LayoutLinearDrawing(ValNodePtr g_bsp_list, Int2 pan_width, Int2 p
 	if(label_align == MSM_LABEL_RIGHT)
 	{
 		left = max_label_len/2;
-		right = pan_width - max_label_len;
+		right = pan_width - (Int2)max_label_len;
 	}
 	else
 	{
@@ -1090,13 +1095,13 @@ static Boolean LayoutLinearDrawing(ValNodePtr g_bsp_list, Int2 pan_width, Int2 p
 	box_height = (Int2)GetMuskCParam(MSM_SEQUENCE, MSM_SEGMENT, MSM_HEIGHT);
 	if(box_height < 6)
 		box_height = 6;
-	maxHeight = num*( box_height + space * 2) + (num -1) * extra_space + align_space + legend_space;
+	maxHeight = num*( box_height + space * 2) + (num -1) * extra_space + align_space + legend_space + lod_num * (box_height + extra_space * 2);
 	if(legend_space > 0 || g_bsp_list->next == NULL || pan_height <= maxHeight)
 		start_height = 0;
 	else
 		start_height = (pan_height - maxHeight)/(num + 1);
 
-	top = legend_space;
+	top = (Int2)legend_space;
 	for(curr = g_bsp_list; curr != NULL; curr = curr->next)
 	{
 		gbp = curr->data.ptrvalue;
@@ -1112,6 +1117,11 @@ static Boolean LayoutLinearDrawing(ValNodePtr g_bsp_list, Int2 pan_width, Int2 p
 			gbp->rec.top = top;
 			gbp->rec.bottom = bottom;
 			top = bottom + space + extra_space + align_space;
+
+			if(gbp->num_lod_score > 0)
+			{
+				top += ((box_height + extra_space * 2)*gbp->num_lod_score);
+			}
 		}
 	}
 
@@ -1362,7 +1372,7 @@ static Boolean draw_human_cyto_map(BioseqPtr bsp, Int4 left, Int4 top, Int4 righ
 			draw_band = TRUE;
 			switch(band)
 			{
-				case POINT:
+				case BAND_POINT:
 					color = RED_COLOR;
 					shading = SOLID_SHADING;
 					break;
@@ -1876,6 +1886,30 @@ static Boolean get_min_max_score (ValNodePtr arp_list, FloatHiPtr min_score, Flo
 }
 
 
+static Uint1Ptr MapLodScoreColor(SeqFeatPtr sfp)
+{
+	Uint1 bit_val;
+
+	bit_val =  GetLODScoreBitValue(sfp);
+	switch(bit_val)
+	{
+		case 1:
+			return BLUE_COLOR;
+		case 2:
+			return CYAN_COLOR;
+		case 3:
+			return GREEN_COLOR;
+		case 4:
+			return YELLOW_COLOR;
+		case 5:
+			return MAGENTA_COLOR;
+		case 6:
+			return RED_COLOR;
+		default:
+			return BLACK_COLOR;
+	}
+}
+	
 	
 
 static Boolean  Draw_Global_Linear(GlobalBspPtr gbp, SegmenT seg, Boolean draw_align_legend)
@@ -1914,6 +1948,9 @@ static Boolean  Draw_Global_Linear(GlobalBspPtr gbp, SegmenT seg, Boolean draw_a
   ValNodePtr delta_node;
   SeqLitPtr slitp;
 
+  SeqAnnotPtr annot;
+  SeqFeatPtr sfp;
+  Int4 extra_space, space;
 
 
 	if(gbp == NULL || gbp->bsp == NULL || gbp->hide)
@@ -2197,7 +2234,46 @@ static Boolean  Draw_Global_Linear(GlobalBspPtr gbp, SegmenT seg, Boolean draw_a
 	if(gbp->has_fish_align == FALSE && gbp->arp_list != NULL)
 		top = add_alignment_to_global(seg, gbp->arp_list, top, TRUE, left, right, length);
 
-	
+
+	/*add the LOD score plot*/
+	if(gbp->num_lod_score > 0)
+	{
+		extra_space = GetMuskCParam(MSM_TOPSTYLE, MSM_SPACE, MSM_HEIGHT);
+		space = get_minimal_spacing();
+		bottom -= space;
+		for(annot = bsp->annot; annot != NULL; annot = annot->next)
+		{
+			if(is_lod_score_annot(annot))
+			{
+				top = bottom -  2* extra_space;
+				bottom = top - (gbp->rec.bottom - gbp->rec.top);
+				for(sfp = annot->data; sfp != NULL; sfp = sfp->next)
+				{
+					color = MapLodScoreColor(sfp);
+					AddAttribute (seg, COLOR_ATT, color, 0, 0, 0, 0);
+					m_start = SeqLocStart(sfp->location);
+					m_stop = SeqLocStop(sfp->location);
+					DrawInterval(m_start, m_stop, length, left, right, top, bottom, TRUE, seg);
+				}
+				add_attribute_pen(seg, MSM_SEQUENCE, MSM_SEG_BORD);
+				AddRectangle (seg, left, top, right, bottom, FALSE, FALSE, 0);
+
+				label = GetAnnotTitle(annot);
+				if(label != NULL)
+				{
+					AddAttribute (seg, COLOR_ATT, BLACK_COLOR, 0, 0, 0, 0);
+					font = (FonT)GetMuskCParam(MSM_SEQUENCE, MSM_SLABEL, MSM_FONT);
+					label_align = (Uint1)GetMuskCParam(MSM_TOPSTYLE, MSM_SLABEL, MSM_STYLE);
+					middle = (top + bottom)/2;
+					if(label_align == MSM_LABEL_RIGHT)
+						AddTextLabel(seg, right, middle, label, font, 0, MIDDLE_RIGHT, 0);
+					else
+						AddTextLabel(seg, left, middle, label, font, 0, MIDDLE_LEFT, 0);
+				}
+			}
+		}
+	}
+				
 	return TRUE;
 }
 
