@@ -30,8 +30,43 @@ Author: Tom Madden
 Contents: #defines and definitions for structures used by BLAST.
 
 ******************************************************************************/
-/* $Revision: 6.162 $ 
+/* $Revision: 6.169 $ 
 * $Log: blastdef.h,v $
+* Revision 6.169  2007/03/13 20:39:58  madden
+*  - Change the type of the dropoff_1st_pass, dropoff_2nd_pass,
+*    gap_x_dropoff, and gap_x_dropoff_final fields of the
+*    BLAST_OptionsBlk struct to Nlm_FloatHi.
+*  [from Mike Gertz]
+*
+* Revision 6.168  2006/05/03 14:41:50  madden
+* Added a Boolean field "unified_p" to the BLAST_OptionsBlk
+* structure.  The field indicates whether to use a combination of
+* alignment and compositional p-values when evaluating significance;
+* the field is ignored unless composition-based statistics is on.
+* (from Mike Gertz).
+*
+* Revision 6.167  2006/03/21 22:35:27  camacho
+* Add support for setting database length in BLAST_WizardOptions{Blk,Mask}
+*
+* Revision 6.166  2006/01/24 18:38:15  papadopo
+* from Mike Gertz: Remove #define'd constants that specify the composition adjustment mode.  These have been replaced by an enum in the composition adjustment library
+*
+* Revision 6.165  2005/08/31 20:32:47  coulouri
+* From Mike Gertz:
+*    - Added the kappa_expect_value field to the
+*      BLAST_OptionsBlk datatype.  This new field holds the cutoff value
+*      used by RedoAlignmentCore; it should equal expect_value if
+*      RedoAlignmentCore will not be called.
+*    - removed the now unused original_expect_value field of the
+*      BLAST_OptionsBlk datatype.
+*
+* Revision 6.164  2005/07/27 15:51:54  coulouri
+* remove unused queue_callback
+*
+* Revision 6.163  2005/05/16 17:43:29  papadopo
+* From Alejandro Schaffer: Added support for compositional score
+* matrix adjustment
+*
 * Revision 6.162  2005/04/25 14:16:36  coulouri
 * set db_chunk_size adaptively
 *
@@ -1064,7 +1099,7 @@ typedef struct _blast_optionsblk {
 	Boolean	multiple_hits_only; /* Only the multiple hits alg. used. */
 	Int4	hitlist_size;	/* How many hits should be returned. */
 	Nlm_FloatHi number_of_bits; /* Number of bits to initiate 2nd pass (default is used if zero) */
-	Int4	dropoff_1st_pass, /* dropoff ("X") used for 1st pass. */
+	Nlm_FloatHi	dropoff_1st_pass, /* dropoff ("X") used for 1st pass. */
                 dropoff_2nd_pass; /* dropoff ("X") used for 2nd pass. */
 	Int2	number_of_cpus;	/* How many CPU's. */
 	CharPtr matrix;		/* name of matrix to use. */
@@ -1082,8 +1117,8 @@ typedef struct _blast_optionsblk {
 	Boolean		gapped_calculation; /* Is a gapped calc. being done? */
 	/* The next three are used ONLY for gapped alignments. */
 	Int4		gap_open,	/* Cost to open a gap (NO extension). */
-			gap_extend,	/* Cost to extend a gap one letter. */
-			gap_x_dropoff,	/* X-dropoff (in bits) used by Gapped align routine. */
+			gap_extend;	/* Cost to extend a gap one letter. */
+        Nlm_FloatHi     gap_x_dropoff,  /* X-dropoff (in bits) used by Gapped align routine. */
 			gap_x_dropoff_final;	/* X-dropoff (in bits) used by Gapped align routine for FINAL alignment. */
         Int4            decline_align;  /* Cost for declining alignment */
 	Nlm_FloatHi	gap_trigger; /* Score (in bits) to gap, if an HSP gaps well. */
@@ -1119,8 +1154,12 @@ typedef struct _blast_optionsblk {
         CharPtr		org_name;	/* user specified name of organizm;  corresponding .gil file will be used */
 	Uint1		strand_option;	/* BLAST_TOP_STRAND, BLAST_BOTTOM_STRAND, or BLAST_BOTH_STRAND.  used by blast[nx] and tblastx */
 	Int4		hsp_num_max;	/* maximum number of HSP's allowed.  Zero indicates no limit. */
-	Boolean		tweak_parameters, /* For impala related stuff. */
+	Uint1		tweak_parameters, /* For composition-based statistics. */
 			smith_waterman;
+        Boolean         unified_p;    /* use a combination of alignment and 
+                                         compositional p-values when evaluating
+                                         significance; ignored unless 
+                                         composition-based statisics is on. */
         CharPtr         phi_pattern;      /* Pattern for PHI-Blast search */
 	Boolean		use_real_db_size; /* Use real DB size.  meant for use if a list of gis' is submitted, 
 					but statistics should be based upon the real database. */
@@ -1132,8 +1171,12 @@ typedef struct _blast_optionsblk {
         SeqLocPtr       query_lcase_mask; /* Masking of input DNA regions */
         Boolean         sort_gi_list;     /* Should the gi list be sorted? */
         Boolean         is_neighboring;   /* Is this a neighboring task? */
-	Nlm_FloatHi original_expect_value;/* Used to change the E-value threshold for 
-			part of a BLAST-KAPPA run and to restore it to the original threshold for the final output. */
+        Nlm_FloatHi kappa_expect_value;   /* E-value threshold for
+                                             hits to be saved when
+                                             RedoAlignmentCore is used
+                                             to compute final alignments;
+                                             should equal expect_value for
+                                             other types of alignment. */
 	Boolean		explode_seqids;	/* make one SeqAlign for every gi on a
 					   redundant sequence. */
         Boolean         megablast_full_deflines; /* Print full deflines in
@@ -1204,12 +1247,13 @@ struct _blast_wizardoptionsblk {
     Int4            required_end;
     Int4            required_start;
     Int2            reward;
+    Int8            db_length;
     Nlm_FloatHi     searchsp_eff;
     Boolean         smith_waterman;
     Uint1           strand_option;
     Int4            threshold_first;
     Int4            threshold_second;
-    Boolean         tweak_parameters;
+    Uint1           tweak_parameters;
     Boolean         use_best_align;
     Boolean         use_real_db_size;
     Int4            window_size;
@@ -1248,6 +1292,7 @@ struct _blast_wizardoptionsmask {
     Boolean         required_end;
     Boolean         required_start;
     Boolean         reward;
+    Boolean         db_length;
     Boolean         searchsp_eff;
     Boolean         smith_waterman;
     Boolean         strand_option;
@@ -1461,6 +1506,7 @@ typedef struct _blast_seg {
 
 #define BLAST_NUMBER_OF_ORDERING_METHODS 2
 
+
 /*
 	The following structure is used in "link_hsps" to decide between
 	two different "gapping" models.  Here link is used to hook up
@@ -1509,6 +1555,9 @@ typedef struct _blast_hsp {
                 GapXEditBlockPtr gap_info; /* ALL gapped alignment is here */
 		Int4 num_ref;
 		Int4 linked_to;
+/*which method if any was used for compositional adjustment?
+  relevant only for blastp*/
+		Int2		comp_adjustment_method; 
 	} BLAST_HSP, PNTR BLAST_HSPPtr;
 
 /* The helper arrays contains the info used frequently in the inner for loops. -cfj
@@ -2054,8 +2103,6 @@ a field is allocated, then it's bit is non-zero.
         prelim_gap_attempts,	/* No. of HSP's we attempted to gap. */
         real_gap_number_of_hsps, /* How many HSP's were gapped in BlastGetGappedScore. */
         semid;                  /* Here will be stored ID of load-ballance semaphore */
-    /* Callback for the queueing system. */
-    int (LIBCALLBACK *queue_callback)PROTO((int semid, int num, int num_cpu));
     GreedyAlignMemPtr abmp; /* Memory for megablast greedy extension */
     Int4 PNTR query_context_offsets; /* offsets for all queries and strands in a 
                                         concatenated sequence */
