@@ -1,3 +1,5 @@
+static char const rcsid[] = "$Id: sim3.c,v 6.2 2003/05/30 17:25:38 coulouri Exp $";
+
 /*
 * sim3.c - compare two very similar sequences with affine gap penalties
 *
@@ -36,20 +38,6 @@
 *
 ********************************************************************/
 
-static EditScriptPtr Script_free(EditScriptPtr head)
-{
-	EditScriptPtr tp, tp1;
-
-	tp = head;
-	while (tp != NULL) {
-	   tp1 = tp->next;
-	   MemFree(tp);
-	   tp = tp1;
-	}
-	return NULL;
-}
-
-
 static Int4 power(Int4 base, Int4 n)
 {
 	Int4 i, p;
