@@ -28,13 +28,37 @@
 *
 * Version Creation Date:   5/01
 *
-* $Revision: 6.11 $
+* $Revision: 6.19 $
 *
 * File Description: mrna-to-genomic alignment algorithms and functions
 *
 * Modifications:
 * --------------------------------------------------------------------------
 * $Log: spidey.h,v $
+* Revision 6.19  2004/03/25 21:20:03  kskatz
+* All SPI_is_acceptor_* functions have been corrected: 'N' no longer contributes to nor subtracts from the score, log odds are calculated and the scores added; they are however all antilogged because there are too many places in the code where the score is expected to be between 0 and 1.  Also, corrected sequence frequency determination in SPI_is_acceptor_user and SPI_is_donor_user, as well as correcting for 'N'. Finally, and this all began with, I added matrices for Dictyostelium - command line -r -m
+*
+* Revision 6.18  2003/04/04 19:42:56  kskatz
+* Added a new command line option (-R) to allow external users to point spidey to a repeat database that it can pass on to blast for filtering repeats
+*
+* Revision 6.17  2002/10/02 16:12:54  kskatz
+* Added a new option to SPI_Options (bigintron_size) that holds a user-supplied maximum size (default = 220000) for introns and requires the option (bool) bigintron to be set to 'TRUE'; The functions affected are SPI_mRNAPtr SPI_AdjustForSplice(), SPI_is_consistent(), and SPI_FindPiece(); note that the default for bigintron_size is not set in SPI_OptionsNew() (yet)
+*
+* Revision 6.16  2002/06/27 11:53:33  wheelan
+* additions to structures to support off-by-one bug fixes and printing of the cds length
+*
+* Revision 6.15  2002/05/07 18:42:53  wheelan
+* changes to support user-defined splice matrices
+*
+* Revision 6.14  2002/04/16 17:54:03  wheelan
+* increased XLINTRON sizes
+*
+* Revision 6.13  2002/04/04 17:17:24  wheelan
+* changed endfuzz to 8
+*
+* Revision 6.12  2002/01/30 19:08:51  wheelan
+* better support for revcomp
+*
 * Revision 6.11  2001/12/18 18:00:18  wheelan
 * add strand
 *
@@ -96,6 +120,12 @@ extern "C" {
 #define SPI_GAPEXTEND  3
 #define SPI_PENALTY   -5
 
+#define SPI_MINBADEXON  6
+#define SPI_MAXBADEXON  11
+#define SPI_BADEXONTHRESH  40
+
+#define SPI_MAXSEQPORT  20000
+
 #define SPI_SPLICETHRESH  0.0001
 
 #define SPI_MAXGAP  4 /* maximum gap allowed in SPI_ExtendAlnAlg */
@@ -110,7 +140,7 @@ extern "C" {
 
 #define SPI_TEENYEXON  6 /* smallest exon to look for */
 
-#define SPI_ENDFUZZ  13 /* if the overall alignment misses less than or equal */
+#define SPI_ENDFUZZ  8 /* if the overall alignment misses less than or equal */
                         /* to this amount on the ends of the mRNA, the        */
                         /* alignment will be extended.                        */
 
@@ -123,11 +153,11 @@ extern "C" {
 
 #define SPI_INTRONSIZE  35000 /* used only to decide whether an mRNA may have fallen */
                               /* off a contig */
-#define SPI_INTRONSIZEXL  120000 /* if spot->bigintron TRUE, use this */
+#define SPI_INTRONSIZEXL  220000 /* if spot->bigintron TRUE, use this */
 
 #define SPI_BIGINTRON  100000 /* max size of 1st and last introns, if 1st and last exons */
                               /* have to be found by SPI_FindPiece. */
-#define SPI_BIGINTRONXL  240000 /* if spot->bigintron TRUE, use this */
+#define SPI_BIGINTRONXL  500000 /* if spot->bigintron TRUE, use this */
 
 #define SPI_PADDING  0 /* how much each region is padded on each side */
 
@@ -171,6 +201,7 @@ extern "C" {
 #define SPI_FLY         2
 #define SPI_PLANT       3
 #define SPI_CELEGANS    4
+#define SPI_DICTY       5
 
 /* return codes for progress callback */
 #define SPI_START     1
@@ -258,6 +289,7 @@ typedef struct spi_reginfo {
    Int4         gstop;
    Int4         mstart;
    Int4         mstop;
+   Int4         mlen;
    Uint1        strand;
    SPI_mRNAPtr  smp;
    Int4         coverage;
@@ -266,6 +298,7 @@ typedef struct spi_reginfo {
    Boolean      fallsoff; /* this mRNA may fall off the end of the genomic sequence */
    SPI_UTRInfo  utr; /* if this is a CDS, UTR %ids are here */
    SPI_MultPtr  smu;
+   Boolean      revcmp_try;
    struct spi_reginfo PNTR next;
 } SPI_RegionInfo, PNTR SPI_RegionInfoPtr;
 
@@ -369,31 +402,46 @@ typedef struct spi_progress {
 
 typedef Boolean (LIBCALLBACK *SPI_ProgressCallback)(SPI_ProgressPtr progress);
 
-typedef struct spi_options {
-   FloatHi               firstpasseval;
-   FloatHi               secpasseval;
-   FloatHi               thirdpasseval;
-   Int4                  organism;
-   Int4                  numreturns;
-   Int4                  idcutoff;
-   Int4                  lencutoff;
-   Int4                  printaln;
-   Boolean               interspecies;
-   Boolean               printasn;
-   SeqAlignPtr           PNTR sap_head;
-   CharPtr               draftfile;
-   SeqLocPtr             lcaseloc;
-   Boolean               fetchcds;
-   Boolean               printheader;
-   Boolean               ace;
-   SPI_ProgressCallback  callback;
-   Int4                  from; /* to restrict genomic interval */
-   Int4                  to;   /* " */
-   Boolean               makemult; /* make a multiple alignment from numerous returns? */
-   Boolean               bigintron;
-   Uint1                 strand; /* to restrict the search to one genomic strand */
-} SPI_Options, PNTR SPI_OptionsPtr;
+typedef struct spi_spliceinfo {
+   FloatHi  a;
+   FloatHi  c;
+   FloatHi  g;
+   FloatHi  t;
+   struct spi_spliceinfo PNTR next;
+} SPI_SpliceInfo, PNTR SPI_SpliceInfoPtr;
 
+typedef struct spi_options {
+    FloatHi               firstpasseval;
+    FloatHi               secpasseval;
+    FloatHi               thirdpasseval;
+    Int4                  organism;
+    Int4                  numreturns;
+    Int4                  idcutoff;
+    Int4                  lencutoff;
+    Int4                  printaln;
+    Boolean               interspecies;
+    Boolean               printasn;
+    SeqAlignPtr           PNTR sap_head;
+    CharPtr               draftfile;
+    CharPtr               repeat_db_file; /* path to repeat db to use */
+    SeqLocPtr             lcaseloc;
+    Boolean               fetchcds;
+    Boolean               printheader;
+    Boolean               ace;
+    SPI_ProgressCallback  callback;
+    Int4                  from; /* to restrict genomic interval */
+    Int4                  to;   /* " */
+    Boolean               makemult; /* make a multiple alignment from numerous returns? */
+    Boolean               bigintron; 
+    Int4                  bigintron_size; /*added by KSK */
+    Uint1                 strand; /* to restrict the search to one genomic strand */
+    Boolean               revcomp;
+    Int4                  dsplicejunc;
+    SPI_SpliceInfoPtr     dssp_head;
+    Int4                  asplicejunc;
+    SPI_SpliceInfoPtr     assp_head;
+} SPI_Options, PNTR SPI_OptionsPtr;
+    
 typedef struct spi_n {
    Int4  n1;
    Int4  n2;
