@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   10/23/92
 *
-* $Revision: 6.4 $
+* $Revision: 6.7 $
 *
 * File Description: 
 *
@@ -40,6 +40,15 @@
 *
 *
 * $Log: picture.c,v $
+* Revision 6.7  2004/02/17 19:22:54  johnson
+* make segment ID consistly unsigned
+*
+* Revision 6.6  2002/08/07 18:13:42  kans
+* G/SetPrimitiveIDs, itemID is Uint4
+*
+* Revision 6.5  2002/03/07 15:53:45  kans
+* added SetSegmentVisibleFlag to set/clear the visible flag before attaching to a viewer
+*
 * Revision 6.4  1999/10/13 17:45:46  kans
 * added entityID, itemID, and itemtype to primitive internal structure, added Get and Set functions
 *
@@ -534,11 +543,11 @@ SegmenT Nlm_ParentSegment (SegmenT segment)
 *
 *****************************************************************************/
 
-Int2 Nlm_SegmentID (SegmenT segment)
+Uint2 Nlm_SegmentID (SegmenT segment)
 
 {
   SegPPtr  seg;
-  Int2     segID;
+  Uint2     segID;
 
   segID = 0;
   if (segment != NULL) {
@@ -577,6 +586,28 @@ Boolean Nlm_SegmentVisible (SegmenT segment)
   return vis;
 }
 
+/*****************************************************************************
+*
+*   Nlm_SetSegmentVisibleFlag (segment, visible)
+*       Sets the visibility of a segment
+*
+*****************************************************************************/
+
+void Nlm_SetSegmentVisibleFlag (SegmenT segment, Boolean visible)
+
+{
+  SegPPtr  seg;
+
+  if (segment != NULL) {
+    seg = (SegPPtr) segment;
+    if (seg->base.code == SEGMENT || seg->base.code == PICTURE) {
+      seg->seg.visible = visible;
+    } else {
+      Message (MSG_ERROR, "Nlm_SetSegmentVisibleFlag argument not a segment or picture");
+    }
+  }
+}
+
 /*****************************************************************************
 *
 *   SegmentStyle (segment)
@@ -655,7 +686,7 @@ PrimitivE Nlm_GetPrimitive (SegmenT segment, Uint2 primCt)
   return (PrimitivE) item;
 }
 
-void Nlm_SetPrimitiveIDs (PrimitivE prim, Uint2 entityID, Uint2 itemID,
+void Nlm_SetPrimitiveIDs (PrimitivE prim, Uint2 entityID, Uint4 itemID,
                           Uint2 itemtype, Uint2 primID)
 
 {
@@ -672,7 +703,7 @@ void Nlm_SetPrimitiveIDs (PrimitivE prim, Uint2 entityID, Uint2 itemID,
   }
 }
 
-void Nlm_GetPrimitiveIDs (PrimitivE prim, Uint2Ptr entityIDPtr, Uint2Ptr itemIDPtr,
+void Nlm_GetPrimitiveIDs (PrimitivE prim, Uint2Ptr entityIDPtr, Uint4Ptr itemIDPtr,
                           Uint2Ptr itemtypePtr, Uint2Ptr primIDPtr)
 
 {
