@@ -29,13 +29,25 @@
 *
 * Version Creation Date:   10/23/92
 *
-* $Revision: 6.11 $
+* $Revision: 6.15 $
 *
 * File Description: 
 *
 * Modifications:  
 * --------------------------------------------------------------------------
 * $Log: picture.h,v $
+* Revision 6.15  2004/02/17 19:22:54  johnson
+* make segment ID consistly unsigned
+*
+* Revision 6.14  2003/03/18 17:00:10  kans
+* Nlm_AddSilentSegRect does not absorb clicks, SegRect reverted to absorb clicks, so desktop click responsiveness is maintained
+*
+* Revision 6.13  2002/08/07 18:13:42  kans
+* G/SetPrimitiveIDs, itemID is Uint4
+*
+* Revision 6.12  2002/03/07 15:53:45  kans
+* added SetSegmentVisibleFlag to set/clear the visible flag before attaching to a viewer
+*
 * Revision 6.11  1999/10/13 17:45:46  kans
 * added entityID, itemID, and itemtype to primitive internal structure, added Get and Set functions
 *
@@ -331,7 +343,7 @@ extern Nlm_SegmenT   Nlm_ResetSegment   PROTO((Nlm_SegmenT segment));
 extern Nlm_SegmenT   Nlm_DeleteSegment  PROTO((Nlm_SegmenT segment));
 
 extern Nlm_SegmenT   Nlm_ParentSegment  PROTO((Nlm_SegmenT segment));
-extern Nlm_Int2      Nlm_SegmentID      PROTO((Nlm_SegmenT segment));
+extern Nlm_Uint2     Nlm_SegmentID      PROTO((Nlm_SegmenT segment));
 extern Nlm_Boolean   Nlm_SegmentVisible PROTO((Nlm_SegmenT segment));
 extern Nlm_Int1      Nlm_SegmentStyle   PROTO((Nlm_SegmenT segment));
 extern void          Nlm_SegmentBox     PROTO((Nlm_SegmenT segment, 
@@ -360,6 +372,8 @@ Nlm_Uint2 primID));
 
 extern Nlm_PrimitivE Nlm_AddSegRect     PROTO((Nlm_SegmenT parent, 
 Nlm_Boolean fill, Nlm_Uint2 primID));
+extern Nlm_PrimitivE Nlm_AddSilentSegRect PROTO((Nlm_SegmenT parent, 
+Nlm_Boolean fill, Nlm_Uint2 primID));
 extern Nlm_PrimitivE Nlm_AddLine        PROTO((Nlm_SegmenT parent, 
 Nlm_Int4 pnt1X, Nlm_Int4 pnt1Y, Nlm_Int4 pnt2X, Nlm_Int4 pnt2Y, 
 Nlm_Boolean arrow, Nlm_Uint2 primID));
@@ -407,11 +421,14 @@ extern void          Nlm_UnlinkSegment      PROTO((Nlm_SegmenT child));
 extern void          Nlm_ExploreSegment     PROTO((Nlm_SegmenT segment, 
 Nlm_VoidPtr userdata, Nlm_SegmentExploreProc callback));
 
+/* SetSegmentVisibleFlag does not change the display in the viewer - use ShowSegment and HideSegment */
+extern void          Nlm_SetSegmentVisibleFlag (Nlm_SegmenT segment, Nlm_Boolean visible);
+
 /*Working with primitive */
 
 extern Nlm_PrimitivE Nlm_GetPrimitive PROTO((Nlm_SegmenT segment, Nlm_Uint2 primCt));
-extern void Nlm_SetPrimitiveIDs PROTO((Nlm_PrimitivE prim, Nlm_Uint2 entityID, Nlm_Uint2 itemID, Nlm_Uint2 itemtype, Nlm_Uint2 primID));
-extern void Nlm_GetPrimitiveIDs PROTO((Nlm_PrimitivE prim, Nlm_Uint2Ptr entityIDPtr, Nlm_Uint2Ptr itemIDPtr, Nlm_Uint2Ptr itemtypePtr, Nlm_Uint2Ptr primIDPtr));
+extern void Nlm_SetPrimitiveIDs PROTO((Nlm_PrimitivE prim, Nlm_Uint2 entityID, Nlm_Uint4 itemID, Nlm_Uint2 itemtype, Nlm_Uint2 primID));
+extern void Nlm_GetPrimitiveIDs PROTO((Nlm_PrimitivE prim, Nlm_Uint2Ptr entityIDPtr, Nlm_Uint4Ptr itemIDPtr, Nlm_Uint2Ptr itemtypePtr, Nlm_Uint2Ptr primIDPtr));
 extern void Nlm_GetPrimDrawAttribute PROTO((Nlm_PrimitivE prim, 
 Nlm_Uint1Ptr color, Nlm_Int1Ptr plinestyle, Nlm_Int1Ptr pshading, 
 Nlm_Int1Ptr ppenwidth, Nlm_Int1Ptr pmode, Nlm_Int1Ptr phighlight));
@@ -487,12 +504,14 @@ extern Nlm_enumPrimAddOrder Nlm_ChangeAddPrimOrder
 #define SegmentVisible Nlm_SegmentVisible
 #define SegmentStyle Nlm_SegmentStyle
 #define SegmentBox Nlm_SegmentBox
+#define SetSegmentVisibleFlag Nlm_SetSegmentVisibleFlag
 #define AddAttribute Nlm_AddAttribute
 #define AddPrimitive Nlm_AddPrimitive
 #define AddInvFrame Nlm_AddInvFrame
 #define AddRectangle Nlm_AddRectangle
 #define AddRoundedRectangle Nlm_AddRoundedRectangle
 #define AddSegRect Nlm_AddSegRect
+#define AddSilentSegRect Nlm_AddSilentSegRect
 #define AddLine Nlm_AddLine
 #define AddSymbol Nlm_AddSymbol
 #define AddBitmap Nlm_AddBitmap
