@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   04/03/95
 *
-* $Revision: 6.0 $
+* $Revision: 6.1 $
 *
 * File Description: 
 *
@@ -159,14 +159,14 @@
    x_cur = arcBufferX[imageptr]/reg1; \
    if ( (x_cur>=arc_xmin)&&(x_cur<=arc_xmax)&& \
         (y_cur>=arc_ymin)&&(y_cur<=arc_ymax) ){ \
-     offset = (y_cur * Nlm_stCon.widthCur + x_cur)<<1; \
+     offset = (y_cur * Nlm_stCon.widthCur + x_cur); \
      zptr_save = zptr; \
-     zptr +=  offset; \
+     zptr += (offset << 1); \
      reg1_save_save = reg1; \
      reg1 = (arcBufferZ[imageptr])/reg1 + z; \
      if( (Uint2)reg1>=*((Uint2Ptr)zptr)) {\
        *((Uint2Ptr)zptr) = (Uint2)reg1; \
-       *((Uint4Ptr)(im_save+(offset<<1))) = (Uint4)curID; \
+       *((VoidPtr*)(im_save+(offset * sizeof(Nlm_stCon.idBuffer[0])))) =curID;\
      } \
      reg1 = reg1_save_save; \
      zptr = zptr_save; \
@@ -1096,9 +1096,10 @@ static void Nlm_Cylin3DHitT ( Nlm_Cylin3DPtr p )
      rad            - radius
      needChk        - 1 if need */
 
-  if ( (c_dx==0) && (c_dy==0) ) return;
-  ystep = Nlm_stCon.widthCur<<2;
-  zystep = ystep>>1;
+  if ( (c_dx==0) && (c_dy==0) )
+    return;
+  ystep  = Nlm_stCon.widthCur * sizeof(Nlm_stCon.idBuffer[0]);
+  zystep = Nlm_stCon.widthCur * sizeof(Nlm_stCon.zBuffer[0]);
 
   /* Elips - start */
   reg2 = c_dx*c_dx + c_dy*c_dy;
@@ -1590,7 +1591,7 @@ static void Nlm_Cylin3DHitT ( Nlm_Cylin3DPtr p )
            reg4 += zystep; 
            reg1 -= dx; 
         }
-        reg3 += 4; reg4++; reg4++;
+        reg3 += sizeof(Nlm_stCon.idBuffer[0]); reg4++; reg4++;
         arc_xmin--;
         arc_xmax--;
         reg2 += zrate; 
@@ -1611,7 +1612,7 @@ static void Nlm_Cylin3DHitT ( Nlm_Cylin3DPtr p )
            reg4 -= zystep; 
            reg1 -= dx; 
         }
-        reg3 += 4; reg4++; reg4++;
+        reg3 += sizeof(Nlm_stCon.idBuffer[0]); reg4++; reg4++;
         arc_xmin--;
         arc_xmax--;
         reg2 += zrate; 
@@ -1626,7 +1627,7 @@ static void Nlm_Cylin3DHitT ( Nlm_Cylin3DPtr p )
       do {
         reg1 += dx;
         if ( reg1 > 0 ) {
-           reg3 += 4;
+           reg3 += sizeof(Nlm_stCon.idBuffer[0]);
            arc_xmin--;
            arc_xmax--;
            reg4 ++; reg4++;
@@ -1648,10 +1649,10 @@ static void Nlm_Cylin3DHitT ( Nlm_Cylin3DPtr p )
       do {
         reg1 += dx;
         if ( reg1 > 0 ) {
-           reg3 += 4;
+           reg3 += sizeof(Nlm_stCon.idBuffer[0]);
            arc_xmin--;
            arc_xmax--;
-           reg4 ++; reg4++;
+           reg4++; reg4++;
            reg1 -= dy; 
         }
         reg3 -= ystep; 
