@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   04/03/95
 *
-* $Revision: 6.1 $
+* $Revision: 6.3 $
 *
 * File Description: 
 *
@@ -65,7 +65,7 @@ if((Uint2)z>=*((Uint2Ptr)zptr)) \
 
 #define SETPIXELID(zptr,imageptr,z,curID) \
 if((Uint2)z>=*((Uint2Ptr)zptr)) \
-{*((Uint2Ptr)zptr)=(Uint2)z;*((Uint4Ptr)imageptr)=(Uint4)curID;}
+{*((Uint2Ptr)zptr)=(Uint2)z;*((VoidPtr*)imageptr)=curID;}
 
 /*****************************************************************************
 *
@@ -214,8 +214,8 @@ static void Nlm_Text3DDraw ( Nlm_Text3DPtr p )
   register long reg2;
   register long reg3;
   register long reg4;
-  long          x1,x2;
-  long          y1,y2;
+  long          x1,x2 = 0;
+  long          y1,y2 = 0;
   long          dx, dy;
   long          xx1,xx2;
   long          yy1,yy2;
@@ -684,8 +684,8 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
   register long reg2;
   register long reg3;
   register long reg4;
-  long          x1,x2;
-  long          y1,y2;
+  long          x1,x2 = 0;
+  long          y1,y2 = 0;
   long          z1,z2;
   long          dx, dy, dz;
   long          xx1,xx2;
@@ -770,8 +770,8 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
 
   ptr = ((Nlm_Text3DPtr)reg1)->text;
   z1 = z2 = z;
-  ystep = Nlm_stCon.widthCur<<2;
-  zystep = ystep>>1;
+  ystep  = Nlm_stCon.widthCur * sizeof(Nlm_stCon.idBuffer[0]);
+  zystep = Nlm_stCon.widthCur * sizeof(Nlm_stCon.zBuffer[0]);
 
   while ( *ptr ){
     if ( (*ptr < 32) || (*ptr > 126) ) continue;
@@ -1128,7 +1128,7 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
                reg4 += zystep; 
                reg1 -= dx; 
             }
-            reg3 += 4; reg4++; reg4++;
+            reg3 += sizeof(Nlm_stCon.idBuffer[0]); reg4++; reg4++;
             reg2 += zrate; 
             curz = reg2;
             reg2 >>= 10;
@@ -1145,7 +1145,7 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
                reg4 -= zystep; 
                reg1 -= dx; 
             }
-            reg3 += 4; reg4++; reg4++;
+            reg3 += sizeof(Nlm_stCon.idBuffer[0]); reg4++; reg4++;
             reg2 += zrate; 
             curz = reg2;
             reg2 >>= 10;
@@ -1158,8 +1158,8 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
           do {
             reg1 += dx;
             if ( reg1 > 0 ) {
-               reg3 += 4;
-               reg4 ++; reg4++;
+               reg3 += sizeof(Nlm_stCon.idBuffer[0]);
+               reg4++; reg4++;
                reg1 -= dy; 
             }
             reg3 += ystep; 
@@ -1176,8 +1176,8 @@ static void Nlm_Text3DHitT ( Nlm_Text3DPtr p )
           do {
             reg1 += dx;
             if ( reg1 > 0 ) {
-               reg3 += 4;
-               reg4 ++; reg4++;
+               reg3 += sizeof(Nlm_stCon.idBuffer[0]);
+               reg4++; reg4++;
                reg1 -= dy; 
             }
             reg3 -= ystep; 
