@@ -31,6 +31,27 @@
 *
 *
 * $Log: treeview.c,v $
+* Revision 1.14  2008/04/29 13:43:50  kans
+* fixes for warnings caught by mingw cross-compiler
+*
+* Revision 1.13  2001/03/28 14:05:47  beloslyu
+* fix the comments to C style
+*
+* Revision 1.12  2001/03/28 01:37:40  juran
+* *** empty log message ***
+*
+* Revision 1.11  2000/11/06 21:51:15  soussov
+* adds code to prevent infinite loop in getNodeCoordinates
+*
+* Revision 1.10  1999/08/12 18:31:10  soussov
+* fixed bug in allocNewSegm
+*
+* Revision 1.9  1999/08/11 14:19:42  soussov
+* fixed bug with Int4 -> Int2 conversion
+*
+* Revision 1.8  1998/07/02 18:24:33  vakatov
+* Cleaned the code & made it pass through the C++ compilation
+*
 * Revision 1.7  1998/04/08 16:51:49  soussov
 * typo in function name fixed
 *
@@ -75,12 +96,43 @@
 
 #define getTree4Cursor tree_getUserData
 
-#define port_MoveTo(p, a, b) MoveTo((a) + (p)->panel_origin_X, (b) + (p)->panel_origin_Y)
-#define port_LineTo(p, a, b) LineTo((a) + (p)->panel_origin_X, (b) + (p)->panel_origin_Y)
+#define port_MoveTo(p, a, b) sMoveTo((a) + (p)->panel_origin_X, (b) + (p)->panel_origin_Y)
+#define port_LineTo(p, a, b) sLineTo((a) + (p)->panel_origin_X, (b) + (p)->panel_origin_Y)
 
 static void closeAllSubtrees(TreeCursorPtr cursor);
 extern void Nlm_GetRect PROTO((Nlm_GraphiC a, Nlm_RectPtr r));
 
+static _tnSegmPtr getNewSegmBuff(void)
+{
+    _tnSegmPtr ts= (_tnSegmPtr)MemNew(4096*sizeof(_tnSegm));
+
+    if(ts) {
+	memset(ts, 0, 4096*sizeof(_tnSegm));
+	ts[4095].flags= LINK_TO_NEXT_BUFF;
+    }
+    return ts;
+}
+
+static void sMoveTo(Int4 x, Int4 y)
+{
+    if(x > 32000) x= 32000;
+    else if(x < -32000) x= -32000;
+    if(y > 32000) y= 32000;
+    else if(y < -32000) y= -32000;
+
+    MoveTo((Int2)x, (Int2)y);
+}
+
+static void sLineTo(Int4 x, Int4 y)
+{
+    if(x > 32000) x= 32000;
+    else if(x < -32000) x= -32000;
+    if(y > 32000) y= 32000;
+    else if(y < -32000) y= -32000;
+
+    LineTo((Int2)x, (Int2)y);
+}
+
 static void port_PaintRect(_drawContextPtr port, RectPtr r)
 {
     r->left+= port->panel_origin_X;
@@ -112,7 +164,7 @@ static CharPtr getNodeLabel(TreeCursorPtr cursor)
     Uint2 size;
     CharPtr label;
 
-    label= tree_getNode(cursor, TREE_NODE_FMT_LABEL, &size);
+    label= (CharPtr) tree_getNode(cursor, TREE_NODE_FMT_LABEL, &size);
     if(label != NULL) label[size]= '\0';
     return label;
 }
@@ -138,6 +190,7 @@ static Int2 getIconId(TreeCursorPtr cursor)
     return id;
 }
     
+#ifdef XXX_UNUSED_STATIC_FUNC
 static void addBox2Region(_boxPtr region, _boxPtr box)
 {
     if(box->xl < region->xl) region->xl= box->xl;
@@ -145,6 +198,7 @@ static void addBox2Region(_boxPtr region, _boxPtr box)
     if(box->yt < region->yt) region->yt= box->yt;
     if(box->yb > region->yb) region->yb= box->yb;
 }
+#endif /* XXX_UNUSED_STATIC_FUNC */
 
 static Boolean BoxXRegion(_boxPtr region, _boxPtr box, _boxPtr res)
 {
@@ -161,6 +215,7 @@ static Boolean BoxXRegion(_boxPtr region, _boxPtr box, _boxPtr res)
     return TRUE;
 }
 
+#ifdef XXX_UNUSED_STATIC_FUNC
 static void moveBox(_boxPtr box, Int4 dx, Int4 dy)
 {
     
@@ -173,7 +228,9 @@ static void moveBox(_boxPtr box, Int4 dx, Int4 dy)
 	box->yb+= dy;
     }
 }
+#endif /* XXX_UNUSED_STATIC_FUNC */
 
+#ifdef XXX_UNUSED_STATIC_FUNC
 static void zoomBox(_boxPtr box, Int4 dx, Int4 dy)
 {
     if(dx != 0) {
@@ -186,6 +243,7 @@ static void zoomBox(_boxPtr box, Int4 dx, Int4 dy)
 	box->yb+= dy;
     }
 }
+#endif /* XXX_UNUSED_STATIC_FUNC */
 
 static Boolean ptInBox(_boxPtr box, Int4 x, Int4 y)
 {
@@ -198,7 +256,7 @@ static void freeNodeSegm(TreeCursorPtr cursor)
     _tnSegmPtr ts2;
     TreeViewPtr tv;
 
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
     ts1= (_tnSegmPtr)(cursor->node->sys_data);
 
     if(ts1 == NULL) return;
@@ -227,37 +285,44 @@ static void freeNodeSegm(TreeCursorPtr cursor)
 static _tnSegmPtr allocNewSegm(TreeCursorPtr cursor)
 {
     _tnSegmPtr ts;
+    _tnSegmPtr tsn;
     TreeViewPtr tv;
-    Int4 i, j;
+    /* Int4 i, j; */
 
     /*find free room */
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
     ts= tv->segm_buff;
 
-    for(i= tv->segm_buff_size; i--; ts++) {
+    while(ts) {
 	if(ts->flags == 0) {
 	    ts->flags= RESERVED_SEGM;
-	    ts->next= cursor->node->sys_data;
+	    ts->next= (_tnSegmPtr)cursor->node->sys_data;
 	    cursor->node->sys_data= ts;
 	    ts->viewer_id= tv->my_spy_id;
 	    return ts;
 	}
+	if((ts->flags & LINK_TO_NEXT_BUFF) != 0) {
+	    if(ts->next) {
+		ts= ts->next;
+		continue;
+	    }
+	    else break;
+	}
+	++ts;
     }
 
+    if(ts == NULL) return NULL;
     /* try to allocate more memory */
-    i= tv->segm_buff_size;
-    tv->segm_buff_size+= tv->segm_buff_size/4;
-    if((ts= MemMore(tv->segm_buff, tv->segm_buff_size*sizeof(_tnSegm))) == NULL) {
-	tv->segm_buff_size= i;	
-	return NULL; /* no more room */
+    if((tsn= getNewSegmBuff()) == NULL) {
+	return NULL;
     }
     
-    for(tv->segm_buff= ts, j= i; i < tv->segm_buff_size; ts[i++].flags= 0);
-    ts[j].flags= RESERVED_SEGM;
-    ts[j].next= cursor->node->sys_data;
-    cursor->node->sys_data= &ts[j];
-    ts[j].viewer_id= tv->my_spy_id;
-    return &ts[j];
+    tsn->flags= RESERVED_SEGM;
+    tsn->viewer_id= tv->my_spy_id;
+    ts->next= tsn;
+    cursor->node->sys_data= tsn;
+    
+    return tsn;
 }
     
     
@@ -294,8 +359,8 @@ static Boolean getBox4Cursor(TreeCursorPtr cursor, _boxPtr box)
     _tnSegmPtr node_data;
     TreeViewPtr tv;
 
-    tv= getTree4Cursor(cursor);
-    if((node_data= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
+    if((node_data= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	box->xr+= node_data->w;
 	box->yb+= node_data->h;
 	return TRUE;
@@ -310,7 +375,7 @@ static TreeNodeId getNextSibling(TreeCursorPtr cursor, TreeNodeId nxt_id)
     _tnSegmPtr node_data;
     TreeViewPtr tv;
 
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr)getTree4Cursor(cursor);
 
     if(nxt_id.idi == cursor->node_id.idi) {
 	nxt_id.idi= 0;
@@ -319,7 +384,7 @@ static TreeNodeId getNextSibling(TreeCursorPtr cursor, TreeNodeId nxt_id)
 
     if(nxt_id.idi != 0) {
 	tree_toNode(cursor, nxt_id);
-	if((node_data= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	if((node_data= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    return node_data->work;
 	}
 	else {
@@ -333,7 +398,7 @@ static TreeNodeId getNextSibling(TreeCursorPtr cursor, TreeNodeId nxt_id)
     if(tree_parent(cursor)) {
 
 	for(r= tree_child(cursor); r; r= tree_sibling(cursor)) {
-	    if((node_data= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	    if((node_data= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 		if((node_data->flags & TREE_FIRST_NODE) != 0) return node_data->work;
 	    }
 	}
@@ -600,7 +665,7 @@ static void setPort2Panel(_drawContextPtr my_port)
 static void drawVertical(TreeCursorPtr cursor, Int4 x0, Int4 y0)
 {
     if(tree_child(cursor)) {
-	TreeViewPtr tv= getTree4Cursor(cursor);
+	TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
 	Int4 y1= y0;
 	Int4 dy= tv->row_height;
 	_tnSegmPtr tns;
@@ -609,7 +674,7 @@ static void drawVertical(TreeCursorPtr cursor, Int4 x0, Int4 y0)
 	    /* we don't want to sort siblings */
 	    do {
 		y1+= dy;
-		if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+		if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 		    dy= tns->h;
 		}
 		else dy= 0;
@@ -621,7 +686,7 @@ static void drawVertical(TreeCursorPtr cursor, Int4 x0, Int4 y0)
 
 	    for(id.idi= 0; (id= getNextSibling(cursor, id)).idi != 0;) {
 		y1+= dy;
-		if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+		if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 		    dy= tns->h;
 		}
 		else dy= 0;
@@ -643,13 +708,12 @@ static Int4 draw_node(TreeCursorPtr cursor, Int4 x0, Int4 y0)
     Int2 icon_id;
     Int4 length;
     CharPtr label;
-    Int2 label_type= 0;
     Boolean need_select= FALSE;
 
     my_box.xl= my_box.xr= x0;
     my_box.yt= my_box.yb= y0;
     if(!getBox4Cursor(cursor, &my_box)) return x0;
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
     icon_id= (tv->i_list == NULL)? -1 : getIconId(cursor);
     length= getNodeLength(cursor);
     label= getNodeLabel(cursor);
@@ -732,7 +796,7 @@ static Boolean drawTree(TreeCursorPtr cursor, Int4 x0, Int4 y0)
     my_box.yt= my_box.yb= y0;
 
     if(!getBox4Cursor(cursor, &my_box)) return FALSE; /* this node is invisible */
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
 
     if(BoxXRegion(&tv->draw_port.clip_box, &my_box, NULL)) {
 	/* we have visible part */
@@ -795,8 +859,8 @@ static Boolean makeNodeVisible(TreeCursorPtr cursor)
     _box my_box;
     _tnSegmPtr tsp;
 
-    tv= getTree4Cursor(cursor);
-    if(getNodeViewerData(cursor->node->sys_data, tv->my_spy_id) != NULL) return TRUE;
+    tv= (TreeViewPtr)getTree4Cursor(cursor);
+    if(getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id) != NULL) return TRUE;
 
     /* we need to open node */
     tsp= allocNewSegm(cursor);
@@ -852,9 +916,8 @@ static void adjust_parentSize(TreeCursorPtr cursor)
     TreeNodeId nid= tree_getId(cursor);
 
     if(tree_parent(cursor)) {
-	tv= getTree4Cursor(cursor);
-	if((tsp= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
-
+	tv= (TreeViewPtr) getTree4Cursor(cursor);
+	if((tsp= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    Int2 icon_id;
 	    Int4 length, xm, ym;
 	    CharPtr label;
@@ -903,7 +966,7 @@ typedef int (*QsortCmpFunc)(const void *, const void *);
 
 static int my_cmpSibl(TreeNodeId* a, TreeNodeId* b)
 {
-    TreeViewPtr tv= getTree4Cursor(sortCursor);
+    TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(sortCursor);
 
     tree_toNode(sortCursor, *b);
     tree_toNode(tv->cr3, *a);
@@ -913,7 +976,7 @@ static int my_cmpSibl(TreeNodeId* a, TreeNodeId* b)
 /* sort siblings */
 static void sortSiblings(TreeCursorPtr cursor, Int2 n)
 {
-    TreeViewPtr tv= getTree4Cursor(cursor);
+    TreeViewPtr tv= (TreeViewPtr)getTree4Cursor(cursor);
     _tnSegmPtr tns;
     int i;
     TreeNodeId nid, save_id= cursor->node_id;
@@ -924,7 +987,7 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
     /* create the array of pointers to viewer structure */
     if(n < 2) {
 	/* we have just one child - nothing to sort */
-	if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    tns->work= cursor->node_id;
 	    tns->flags|= TREE_FIRST_NODE;
 	}
@@ -933,7 +996,7 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
     }
 
     for(i= 0; i < n;) {
-	if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    tns->work.idi= 0;
 	    tns->flags&= ~TREE_FIRST_NODE;
 	}
@@ -948,7 +1011,7 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
 
     /* sort it */
 #if 1
-    if((n > 132) && ((aref= malloc(sizeof(TreeNodeId)*n)) != NULL)) {
+    if((n > 132) && ((aref= (TreeNodeId*)malloc(sizeof(TreeNodeId)*n)) != NULL)) {
 	
 	sortCursor= cursor;
 
@@ -960,19 +1023,19 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
 	qsort((void*)aref, i, sizeof(TreeNodeId), (QsortCmpFunc)my_cmpSibl);
 
 	tree_toNode(cursor, aref[0]);
-	if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    tns->flags|= TREE_FIRST_NODE;
 	}
 
 	for(n= 1; n < i; n++) {
 	    tree_toNode(cursor, aref[n-1]);
-	    if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	    if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 		tns->work= aref[n];
 	    }
 	}
 
 	tree_toNode(cursor, aref[i-1]);
-	if((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) {
+	if((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) {
 	    tns->work= aref[i-1];
 	}
 	
@@ -986,14 +1049,14 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
     for(i= 0; i < n; i++) {
 	/* find the minimum */
 	do {
-	    if(((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) && 
+	    if(((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) && 
 	       (tns->work.idi == 0)) break;
 	}
 	while(tree_sibling(cursor));
 
 	tree_toNode(tv->cr3, tree_getId(cursor));
 	while(tree_sibling(tv->cr3)) {
-	    if(((tns= getNodeViewerData(tv->cr3->node->sys_data, tv->my_spy_id)) != NULL) && 
+	    if(((tns= getNodeViewerData((_tnSegmPtr)tv->cr3->node->sys_data, tv->my_spy_id)) != NULL) && 
 	       (tns->work.idi == 0) && ((*(tv->cmpSiblings))(tv->cr3, cursor) < 0)) {
 
 		tree_toNode(cursor, tree_getId(tv->cr3));
@@ -1001,7 +1064,7 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
 	}
 
 
-	if(((tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) != NULL) && 
+	if(((tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) != NULL) && 
 	   (tns->work.idi == 0)) {
 
 	    tns->work= tree_getId(cursor);
@@ -1010,7 +1073,7 @@ static void sortSiblings(TreeCursorPtr cursor, Int2 n)
 	    }
 	    else {
 		tree_toNode(tv->cr3, nid);
-		tns= getNodeViewerData(tv->cr3->node->sys_data, tv->my_spy_id);
+		tns= getNodeViewerData((_tnSegmPtr)tv->cr3->node->sys_data, tv->my_spy_id);
 		tns->work= tree_getId(cursor);
 	    }
 	    nid= tree_getId(cursor);
@@ -1033,8 +1096,8 @@ static Boolean openSubtree(TreeCursorPtr cursor, Boolean do_callBack)
     TreeNodeId save_id= cursor->node_id;
 
 
-    tv= getTree4Cursor(cursor);
-    if((node_data= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) == NULL) {
+    tv= (TreeViewPtr)getTree4Cursor(cursor);
+    if((node_data= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) == NULL) {
 	return FALSE;
     }
 
@@ -1095,12 +1158,11 @@ static Boolean closeSubtree(TreeCursorPtr cursor, Boolean do_callBack)
     Int2 icon_id;
     Int4 length;
     CharPtr label;
-    Boolean res;
     TreeNodeId nid= cursor->node_id;
 
 
-    tv= getTree4Cursor(cursor);
-    if((tsp= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id)) == NULL) {
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
+    if((tsp= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id)) == NULL) {
 	return FALSE;
     }
 
@@ -1341,7 +1403,7 @@ static Int2 find_node4xy(TreeCursorPtr cursor, Int4 my_x, Int4 my_y, Int4Ptr px,
 
     if(!ptInBox(&my_box, *px, *py)) return 0;
 
-    tv= getTree4Cursor(cursor);
+    tv= (TreeViewPtr) getTree4Cursor(cursor);
 
     length= getNodeLength(cursor);
     my_x+= ((tv->length_scale >= 0)? 
@@ -1406,20 +1468,18 @@ static Int2 find_Node4Point(TreeViewPtr tv, Int4Ptr x, Int4Ptr y)
 
 static void node_open_close(TreeCursorPtr cursor, Int4 x, Int4 y)
 {
-    TreeViewPtr tv= getTree4Cursor(cursor);
+    TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
     _tnSegmPtr tns;
     Boolean need_resize;
-    TreeNodeId crn_id= tree_getId(cursor);
-
     
-    tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id);
+    tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id);
     if(tns == NULL) return;
 
     need_resize= (tns->h > tv->row_height)? closeSubtree(tv->cr1, TRUE) : openSubtree(tv->cr1, TRUE);
 
     if(need_resize) {
 	tree_toNode(cursor, tv->my_root); /*tree_root(cursor);*/
-	tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id);
+	tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id);
 
 	setPort2Panel(&tv->draw_port);
 	
@@ -1443,7 +1503,7 @@ static void node_open_close(TreeCursorPtr cursor, Int4 x, Int4 y)
 
 static CharPtr calcBox4Select(TreeCursorPtr cursor, Int4 x0, Int4 y0, _boxPtr sel_box)
 {
-    TreeViewPtr tv= getTree4Cursor(cursor);
+    TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
     Int4 length= getNodeLength(cursor);
     Int2 icon_id= getIconId(cursor);
     CharPtr label= getNodeLabel(cursor);
@@ -1459,7 +1519,7 @@ static CharPtr calcBox4Select(TreeCursorPtr cursor, Int4 x0, Int4 y0, _boxPtr se
 	
 static void select_treeNode(TreeCursorPtr cursor, Int4 x, Int4 y)
 {
-    TreeViewPtr tv= getTree4Cursor(cursor);
+    TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
     _box my_box;
     CharPtr label;
     
@@ -1596,185 +1656,191 @@ typedef enum {
 } TreeEvent;
 */
 static void spy_proc(TreePtr tree, Int2 spy_id, TreeEvent event, 
-		     TreeNodeId id1, TreeNodeId id2, VoidPtr node_data, Int2 node_data_size)
+                     TreeNodeId id1, TreeNodeId id2, VoidPtr node_data,
+                     Int2 node_data_size)
 {
     static int tran_level= 0;
     static TreeEvent tran_stack[8];
-    TreeViewPtr tv= tree_getSpyData(tree, spy_id);
+    TreeViewPtr tv= (TreeViewPtr) tree_getSpyData(tree, spy_id);
     _tnSegmPtr tns;
     Boolean need_redraw= FALSE;
 
     switch(event) {
     case TREE_NODE_UPDATE: /* node will be updated */
-	tree_toNode(tv->cr4, id1);
-	if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-	    freeNodeSegm(tv->cr4);
-	    tran_stack[tran_level++]= TREE_NODE_UPDATE;
-	}
-	else {
-	    tran_stack[tran_level++]= TREE_CURSOR_MOVED;
-	}
-	break;
+        tree_toNode(tv->cr4, id1);
+        if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+            freeNodeSegm(tv->cr4);
+            tran_stack[tran_level++]= TREE_NODE_UPDATE;
+        }
+        else {
+            tran_stack[tran_level++]= TREE_CURSOR_MOVED;
+        }
+        break;
     case TREE_NODE_UPD_DONE: /* node was updated */
     case TREE_NODEDATA_UPD_DONE:
-	if(tran_stack[--tran_level] == TREE_NODE_UPDATE) {
-	    if(tree_parent(tv->cr4)) {
-		openSubtree(tv->cr4, FALSE);
-	    }
-	    else {
-		makeNodeVisible(tv->cr4);
-	    }
-	    need_redraw= TRUE;
-	}
-	break;
+        if(tran_stack[--tran_level] == TREE_NODE_UPDATE) {
+            if(tree_parent(tv->cr4)) {
+                openSubtree(tv->cr4, FALSE);
+            }
+            else {
+                makeNodeVisible(tv->cr4);
+            }
+            need_redraw= TRUE;
+        }
+        break;
 
     case TREE_NODEDATA_UPDATE: /* node will be updated */
-	if(tran_stack[tran_level - 1] == TREE_NODE_UPDATE) {
-	    tran_stack[tran_level++]= TREE_CURSOR_MOVED;
-	}
-	else {
-	    tree_toNode(tv->cr4, id1);
-	    if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-		freeNodeSegm(tv->cr4);
-		tran_stack[tran_level++]= TREE_NODE_UPDATE;
-	    }
-	    else {
-		tran_stack[tran_level++]= TREE_CURSOR_MOVED;
-	    }
-	}
-	break;
+        if(tran_stack[tran_level - 1] == TREE_NODE_UPDATE) {
+            tran_stack[tran_level++]= TREE_CURSOR_MOVED;
+        }
+        else {
+            tree_toNode(tv->cr4, id1);
+            if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+                freeNodeSegm(tv->cr4);
+                tran_stack[tran_level++]= TREE_NODE_UPDATE;
+            }
+            else {
+                tran_stack[tran_level++]= TREE_CURSOR_MOVED;
+            }
+        }
+        break;
 
     case TREE_NODE_DELETE: /* node will be deleted */
-	tree_toNode(tv->cr4, id1);
-	if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-	    freeNodeSegm(tv->cr4);
-	    tran_stack[tran_level++]= TREE_NODE_DELETE;
-	    tree_toNode(tv->cr4, id2);
-	    closeSubtree(tv->cr4, FALSE);
-	}
-	else {
-	    tran_stack[tran_level++]= TREE_CURSOR_MOVED;
-	}
-	tree_parent(tv->cr4);
-	break;
+        tree_toNode(tv->cr4, id1);
+        if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+            freeNodeSegm(tv->cr4);
+            tran_stack[tran_level++]= TREE_NODE_DELETE;
+            tree_toNode(tv->cr4, id2);
+            closeSubtree(tv->cr4, FALSE);
+        }
+        else {
+            tran_stack[tran_level++]= TREE_CURSOR_MOVED;
+        }
+        tree_parent(tv->cr4);
+        break;
 
     case TREE_SUBTREE_DEL_DONE:
     case TREE_NODE_DEL_DONE: /* node was deleted */
-	tree_toNode(tv->cr4, id1);
-	if(tran_stack[--tran_level] == TREE_NODE_DELETE) {
-	    openSubtree(tv->cr4, FALSE);
-	    need_redraw= TRUE;
-	}
-	break;
+        tree_toNode(tv->cr4, id1);
+        if(tran_stack[--tran_level] == TREE_NODE_DELETE) {
+            openSubtree(tv->cr4, FALSE);
+            need_redraw= TRUE;
+        }
+        break;
 
     case TREE_NODE_MOVE: /* node will be moved */
-	tree_toNode(tv->cr4, id2);
-	if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-	    /* node is visible */
-	    tree_parent(tv->cr4);
-	}
-	else {
-	    tree_toNode(tv->cr4, id1);
-	}
-	break;
+        tree_toNode(tv->cr4, id2);
+        if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+            /* node is visible */
+            tree_parent(tv->cr4);
+        }
+        else {
+            tree_toNode(tv->cr4, id1);
+        }
+        break;
 
     case TREE_NODE_MV_DONE: /* node has been moved */
-	if(tv->cr4->node_id.idi != id1.idi) {
-	    need_redraw= openSubtree(tv->cr4, FALSE);
-	    tree_toNode(tv->cr4, id1);
-	}
-	need_redraw|= openSubtree(tv->cr4, FALSE);
-	break;
+        if(tv->cr4->node_id.idi != id1.idi) {
+            need_redraw= openSubtree(tv->cr4, FALSE);
+            tree_toNode(tv->cr4, id1);
+        }
+        need_redraw|= openSubtree(tv->cr4, FALSE);
+        break;
 
     case TREE_CHILDREN_MOVE: /* children will be moved */
-	tree_toNode(tv->cr4, id2);
-	if(((tns= getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id)) != NULL) &&
-	   (tns->h > tv->row_height)) {
-	    need_redraw= closeSubtree(tv->cr4, TRUE);
-	}
-	break;
+        tree_toNode(tv->cr4, id2);
+        if(((tns= getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id)) != NULL) &&
+           (tns->h > tv->row_height)) {
+            need_redraw= closeSubtree(tv->cr4, TRUE);
+        }
+        break;
 
     case TREE_CHILDREN_MV_DONE: /* children have been moved */
-	tree_toNode(tv->cr4, id1);
-	if((tns= getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id)) == NULL) {
-	    /* this node is invisible */
-	    for(need_redraw= tree_child(tv->cr4); need_redraw; need_redraw= tree_sibling(tv->cr4)) {
-		if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-		    freeNodeSegm(tv->cr4);
-		}
-	    }
-	}
-	else {
-	    closeSubtree(tv->cr4, FALSE);
-	    need_redraw= openSubtree(tv->cr4, TRUE);
-	}
-	break;
+        tree_toNode(tv->cr4, id1);
+        if((tns= getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id)) == NULL) {
+            /* this node is invisible */
+            for(need_redraw= tree_child(tv->cr4); need_redraw; need_redraw= tree_sibling(tv->cr4)) {
+                if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+                    freeNodeSegm(tv->cr4);
+                }
+            }
+        }
+        else {
+            closeSubtree(tv->cr4, FALSE);
+            need_redraw= openSubtree(tv->cr4, TRUE);
+        }
+        break;
 		
     case TREE_SUBTREE_DELETE: /* subtree will be deleted */
-	tree_toNode(tv->cr4, id1);
-	if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-	    /* this node is visible */
+        tree_toNode(tv->cr4, id1);
+        if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+            /* this node is visible */
 	    
-	    tran_stack[tran_level++]= TREE_NODE_DELETE;
-	}
-	else {
-	    tran_stack[tran_level++]= TREE_CURSOR_MOVED;
-	}
-	closeAllSubtrees(tv->cr4);
-	tree_parent(tv->cr4);
-	break;
+            tran_stack[tran_level++]= TREE_NODE_DELETE;
+        }
+        else {
+            tran_stack[tran_level++]= TREE_CURSOR_MOVED;
+        }
+        closeAllSubtrees(tv->cr4);
+        tree_parent(tv->cr4);
+        break;
 	
     case TREE_NODE_MERGE: /* nodes will be merged */
-	tree_toNode(tv->cr4, id2);
-	if(getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
-	    /* this node is visible */
-	    freeNodeSegm(tv->cr4);
-	}
-	break;
+        tree_toNode(tv->cr4, id2);
+        if(getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id) != NULL) {
+            /* this node is visible */
+            freeNodeSegm(tv->cr4);
+        }
+        break;
 
     case TREE_NODE_MERGE_DONE: /* nodes was merged */
-	tree_toNode(tv->cr4, id2);
-	openSubtree(tv->cr4, TRUE);
-	tree_toNode(tv->cr4, id1);
-	openSubtree(tv->cr4, TRUE);
-	need_redraw= TRUE;
-	break;
+        tree_toNode(tv->cr4, id2);
+        openSubtree(tv->cr4, TRUE);
+        tree_toNode(tv->cr4, id1);
+        openSubtree(tv->cr4, TRUE);
+        need_redraw= TRUE;
+        break;
 
     case TREE_NODE_ADDED: /* new node was added */
-	tree_toNode(tv->cr4, id1);
-	need_redraw= openSubtree(tv->cr4, TRUE);
-	break;
+        tree_toNode(tv->cr4, id1);
+        need_redraw= openSubtree(tv->cr4, TRUE);
+        break;
 	    
+    case TREE_CURSOR_MOVED:
+        break;  /* do nothing */
+	    
+    case TREE_SHUTDOWN:
+        break;
     }
     
 
 
     if(need_redraw) {
-	tree_toNode(tv->cr4, tv->my_root); /*tree_root(tv->cr4);*/
-	tns= getNodeViewerData(tv->cr4->node->sys_data, tv->my_spy_id);
+        tree_toNode(tv->cr4, tv->my_root); /*tree_root(tv->cr4);*/
+        tns= getNodeViewerData((_tnSegmPtr)tv->cr4->node->sys_data, tv->my_spy_id);
 
-	setPort2Panel(&tv->draw_port);
+        setPort2Panel(&tv->draw_port);
 	
-	CorrectScrollbar(GetSlateHScrollBar((SlatE)(tv->draw_port.tree_panel)),
-			 tv->row_width, tns->w + 16, tv->draw_port.clip_box.xl, tv->draw_port.clip_box.xr);
+        CorrectScrollbar(GetSlateHScrollBar((SlatE)(tv->draw_port.tree_panel)),
+                         tv->row_width, tns->w + 16, tv->draw_port.clip_box.xl, tv->draw_port.clip_box.xr);
 
-	CorrectScrollbar(GetSlateVScrollBar((SlatE)(tv->draw_port.tree_panel)),
-			 tv->row_height, tns->h + 24, tv->draw_port.clip_box.yt, tv->draw_port.clip_box.yb);
-	tv->sel_y= -1024;
-	tview_redraw(tv);
+        CorrectScrollbar(GetSlateVScrollBar((SlatE)(tv->draw_port.tree_panel)),
+                         tv->row_height, tns->h + 24, tv->draw_port.clip_box.yt, tv->draw_port.clip_box.yb);
+        tv->sel_y= -1024;
+        tview_redraw(tv);
     }
 }
 
 static void close_proc(WindoW w)
 {
-    TreeViewPtr tv= GetWindowExtra(w);
+    TreeViewPtr tv= (TreeViewPtr) GetWindowExtra(w);
     
     tview_delete(tv, 0);
 }
 
 static void resize_proc(WindoW w)
 {
-    TreeViewPtr tv= GetWindowExtra(w);
+    TreeViewPtr tv= (TreeViewPtr) GetWindowExtra(w);
     RecT r;
     _tnSegmPtr tns;
 
@@ -1795,7 +1861,7 @@ static void resize_proc(WindoW w)
 
     /* we need to correct scroll bars here */
     tree_toNode(tv->cr1, tv->my_root); /*tree_root(tv->cr1);*/
-    tns= getNodeViewerData(tv->cr1->node->sys_data, tv->my_spy_id);
+    tns= getNodeViewerData((_tnSegmPtr)tv->cr1->node->sys_data, tv->my_spy_id);
 
     CorrectScrollbar(GetSlateHScrollBar((SlatE)(tv->draw_port.tree_panel)),
 		     tv->row_width, tns->w + 16, tv->draw_port.clip_box.xl, tv->draw_port.clip_box.xr);
@@ -1825,7 +1891,7 @@ void tview_resize(TreeViewPtr tv, RectPtr r)
 
     /* we need to correct scroll bars here */
     tree_toNode(tv->cr1, tv->my_root); /*tree_root(tv->cr1);*/
-    tns= getNodeViewerData(tv->cr1->node->sys_data, tv->my_spy_id);
+    tns= getNodeViewerData((_tnSegmPtr)tv->cr1->node->sys_data, tv->my_spy_id);
 
     CorrectScrollbar(GetSlateHScrollBar((SlatE)(tv->draw_port.tree_panel)),
 		     tv->row_width, tns->w + 16, tv->draw_port.clip_box.xl, tv->draw_port.clip_box.xr);
@@ -1840,7 +1906,7 @@ void tview_resize(TreeViewPtr tv, RectPtr r)
 static void tv_cr2_callback(TreeCursorPtr cursor, TreeEvent event, TreeNodeId id)
 {
     if(event == TREE_CURSOR_MOVED) {
-	TreeViewPtr tv= getTree4Cursor(cursor);
+	TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
 
 	if(tv->evntFunc != NULL) {
 	    (*(tv->evntFunc))(cursor, TVIEW_ON_SELECT);
@@ -1852,10 +1918,10 @@ static void tv_cr2_callback(TreeCursorPtr cursor, TreeEvent event, TreeNodeId id
 static void tv_cr5_callback(TreeCursorPtr cursor, TreeEvent event, TreeNodeId id)
 {
     if(event == TREE_CURSOR_MOVED) {
-	TreeViewPtr tv= getTree4Cursor(cursor);
+	TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
 
 	tv->my_root= id;
-	if(getNodeViewerData(cursor->node->sys_data, tv->my_spy_id) == NULL) {
+	if(getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id) == NULL) {
 	    tree_parent(cursor);
 	}
     }
@@ -1867,19 +1933,16 @@ TreeViewPtr tview_create(GrouP parent, Int2 width, Int2 height,
 			 TreeNodeCmpFunc NodeCmp)
 {
     TreeViewPtr tv;
-    int i;
+    /* int i; */
     _tnSegmPtr tns;
 
-    if((tv= MemNew(sizeof(TreeView))) == NULL) return NULL;
+    if((tv= (TreeViewPtr) MemNew(sizeof(TreeView))) == NULL) return NULL;
 
-    if((tv->segm_buff= MemNew(4096*sizeof(_tnSegm))) == NULL) {
+    if((tv->segm_buff= getNewSegmBuff()) == NULL) {
 	MemFree(tv);
 	return NULL;
     }
 
-    tv->segm_buff_size= 4096;
-
-    for(i= 0; i != 4096; tv->segm_buff[i++].flags= 0);
 
     if(parent == NULL) {
 	/* we need to create window for tree view */
@@ -1976,19 +2039,16 @@ TreeViewPtr tview_createCustom(Int2 left, Int2 top, Int2 width, Int2 height,
 			 TreeNodeCmpFunc NodeCmp)
 {
     TreeViewPtr tv;
-    int i;
+    /* int i; */
     _tnSegmPtr tns;
 
-    if((tv= MemNew(sizeof(TreeView))) == NULL) return NULL;
+    if((tv= (TreeViewPtr) MemNew(sizeof(TreeView))) == NULL) return NULL;
 
-    if((tv->segm_buff= MemNew(4096*sizeof(_tnSegm))) == NULL) {
+    if((tv->segm_buff= getNewSegmBuff()) == NULL) {
 	MemFree(tv);
 	return NULL;
     }
 
-    tv->segm_buff_size= 4096;
-
-    for(i= 0; i != 4096; tv->segm_buff[i++].flags= 0);
 
     /* we need to create window for tree view */
     tv->draw_port.tree_window= DocumentWindow(left, top, -10, -10, title, close_proc, resize_proc);
@@ -2141,8 +2201,8 @@ Int2 tview_distanceCmp(TreeCursorPtr c1, TreeCursorPtr c2)
 
 static void resortNodes(TreeCursorPtr cursor)
 {
-    TreeViewPtr tv= getTree4Cursor(cursor);
-    _tnSegmPtr tns= getNodeViewerData(cursor->node->sys_data, tv->my_spy_id);
+    TreeViewPtr tv= (TreeViewPtr) getTree4Cursor(cursor);
+    _tnSegmPtr tns= getNodeViewerData((_tnSegmPtr)cursor->node->sys_data, tv->my_spy_id);
     TreeNodeId nid= tree_getId(cursor);
     Boolean res;
 
@@ -2240,7 +2300,7 @@ void tview_redraw(TreeViewPtr tv)
 	setPort2Panel(&tv->draw_port);
 	
 	tree_toNode(tv->cr1, tv->my_root); /*tree_root(cursor);*/
-	tns= getNodeViewerData(tv->cr1->node->sys_data, tv->my_spy_id);
+	tns= getNodeViewerData((_tnSegmPtr)tv->cr1->node->sys_data, tv->my_spy_id);
 
 	setPort2Panel(&tv->draw_port);
 	
@@ -2294,7 +2354,7 @@ static void getNodeCoordinates(TreeViewPtr tv, Int4Ptr node_x, Int4Ptr node_y)
 
     while(tv->cr1->node_id.idi != nid.idi) {
 
-	tns= getNodeViewerData(tv->cr1->node->sys_data, tv->my_spy_id);
+	tns= getNodeViewerData((_tnSegmPtr)tv->cr1->node->sys_data, tv->my_spy_id);
 	if(tns == NULL) break;
 	if(tns->h <= tv->row_height) {
 	    openSubtree(tv->cr1, TRUE);
@@ -2331,6 +2391,9 @@ static void getNodeCoordinates(TreeViewPtr tv, Int4Ptr node_x, Int4Ptr node_y)
 		}
 	    }
 	}
+	else {
+	    break;
+	}
     }
 
     *node_x= x;
@@ -2488,6 +2551,8 @@ static void closeAllSubtrees(TreeCursorPtr cursor)
 	
 void tview_delete(TreeViewPtr tv, Boolean do_hide)
 {
+    _tnSegmPtr ts;
+    _tnSegmPtr tsn;
     /* close all subtrees */
     tree_root(tv->cr1);
     closeAllSubtrees(tv->cr1);
@@ -2507,7 +2572,10 @@ void tview_delete(TreeViewPtr tv, Boolean do_hide)
 	Remove(tv->draw_port.tree_window);
     }
 
-    if(tv->segm_buff != NULL) MemFree(tv->segm_buff);
+    for(ts= tv->segm_buff; ts != NULL; ts= tsn) {
+	tsn= ts[4095].next;
+	MemFree(ts);
+    }
     MemFree(tv);
 }
 	
@@ -2517,7 +2585,7 @@ Boolean tview_moveRoot(TreeViewPtr tv, TreeNodeId id)
     BaR b;
 
     if(tree_toNode(tv->cr1, id)) {
-	tns= getNodeViewerData(tv->cr1->node->sys_data, tv->my_spy_id);
+	tns= getNodeViewerData((_tnSegmPtr)tv->cr1->node->sys_data, tv->my_spy_id);
 	if(tns == NULL) {
 	    
 	    tns= allocNewSegm(tv->cr1);
@@ -2530,7 +2598,7 @@ Boolean tview_moveRoot(TreeViewPtr tv, TreeNodeId id)
 	}
 	openSubtree(tv->cr1, TRUE);
 
-	tns= getNodeViewerData(tv->cr5->node->sys_data, tv->my_spy_id);
+	tns= getNodeViewerData((_tnSegmPtr)tv->cr5->node->sys_data, tv->my_spy_id);
 
 	setPort2Panel(&tv->draw_port);
 	
